@@ -19,8 +19,6 @@
 import struct
 import zlib
 
-from .static_tuple import StaticTuple
-
 _LeafNode = None
 _InternalNode = None
 _unknown = None
@@ -96,7 +94,7 @@ def _deserialise_leaf_node(data, key, search_key_func=None):
         value_lines = lines[pos : pos + num_value_lines]
         pos += num_value_lines
         value = b"\n".join(value_lines)
-        items[StaticTuple.from_sequence(elements[:-1])] = value
+        items[tuple(elements[:-1])] = value
     if len(items) != length:
         raise AssertionError(
             f"item count ({length}) mismatch for key {key}, bytes {bytes!r}"
@@ -148,9 +146,7 @@ def _deserialise_internal_node(data, key, search_key_func=None):
     for line in lines[5:]:
         line = common_prefix + line
         prefix, flat_key = line.rsplit(b"\x00", 1)
-        items[prefix] = StaticTuple(
-            flat_key,
-        )
+        items[prefix] = (flat_key,)
     if len(items) == 0:
         raise AssertionError("We didn't find any item for {}".format(key))
     result._items = items
