@@ -38,15 +38,21 @@ Densely packed upper nodes.
 
 import heapq
 import threading
-from typing import Callable
+from collections.abc import Callable, Generator, Iterator
+from typing import Callable, Optional, Union
 
 from .. import errors, lru_cache, osutils, registry, trace
-from .static_tuple import StaticTuple, expect_static_tuple
 
 # approx 4MB
 # If each line is 50 bytes, and you have 255 internal pages, with 255-way fan
 # out, it takes 3.1MB to cache the layer.
 _PAGE_CACHE_SIZE = 4 * 1024 * 1024
+
+Key = tuple[bytes, ...]
+SerialisedKey = bytes
+SearchKeyFunc = Callable[[Key], bytes]
+KeyFilter = list[Key]
+
 # Per thread caches for 2 reasons:
 # - in the server we may be serving very different content, so we get less
 #   cache thrashing.
@@ -80,12 +86,12 @@ _INTERESTING_NEW_SIZE = 50
 _INTERESTING_SHRINKAGE_LIMIT = 20
 
 
-def _search_key_plain(key):
+def _search_key_plain(key: Key) -> SerialisedKey:
     """Map the key tuple into a search string that just uses the key bytes."""
     return b"\x00".join(key)
 
 
-search_key_registry = registry.Registry[bytes, Callable[[bytes], bytes]]()
+search_key_registry = registry.Registry[bytes, Callable[[Key], SerialisedKey]]()
 search_key_registry.register(b"plain", _search_key_plain)
 
 
@@ -93,8 +99,14 @@ class CHKMap:
     """A persistent map from string to string backed by a CHK store."""
 
     __slots__ = ("_root_node", "_search_key_func", "_store")
+    _root_node: "Node"
 
-    def __init__(self, store, root_key, search_key_func=None):
+    def __init__(
+        self,
+        store,
+        root_key: Optional[Key],
+        search_key_func: Optional[SearchKeyFunc] = None,
+    ):
         """Create a CHKMap object.
 
         :param store: The store the CHKMap is stored in.
@@ -123,9 +135,8 @@ class CHKMap:
         """
         has_deletes = False
         # Check preconditions first.
-        as_st = StaticTuple.from_sequence
         new_items = {
-            as_st(key) for (old, key, value) in delta if key is not None and old is None
+            tuple(key) for (old, key, value) in delta if key is not None and old is None
         }
         existing_new = list(self.iteritems(key_filter=new_items))
         if existing_new:
@@ -144,13 +155,13 @@ class CHKMap:
             self._check_remap()
         return self._save()
 
-    def _ensure_root(self):
+    def _ensure_root(self) -> None:
         """Ensure that the root node is an object not a key."""
-        if isinstance(self._root_node, StaticTuple):
+        if isinstance(self._root_node, tuple):
             # Demand-load the root
             self._root_node = self._get_node(self._root_node)
 
-    def _get_node(self, node):
+    def _get_node(self, node: Union[Key, "Node"]) -> "Node":
         """Get a node.
 
         Note that this does not update the _items dict in objects containing a
@@ -160,13 +171,13 @@ class CHKMap:
         :param node: A tuple key or node object.
         :return: A node object.
         """
-        if isinstance(node, StaticTuple):
+        if isinstance(node, tuple):
             bytes = self._read_bytes(node)
             return _deserialise(bytes, node, search_key_func=self._search_key_func)
         else:
             return node
 
-    def _read_bytes(self, key):
+    def _read_bytes(self, key: Key) -> bytes:
         try:
             return _get_cache()[key]
         except KeyError:
@@ -175,7 +186,7 @@ class CHKMap:
             _get_cache()[key] = bytes
             return bytes
 
-    def _dump_tree(self, include_keys=False, encoding="utf-8"):
+    def _dump_tree(self, include_keys: bool = False, encoding: str = "utf-8") -> str:
         """Return the tree in a string representation."""
         self._ensure_root()
 
@@ -192,7 +203,9 @@ class CHKMap:
         res.append("")  # Give a trailing '\n'
         return "\n".join(res)
 
-    def _dump_tree_node(self, node, prefix, indent, decode, include_keys=True):
+    def _dump_tree_node(
+        self, node: "Node", prefix, indent, decode, include_keys: bool = True
+    ) -> list[str]:
         """For this node and all children, generate a string representation."""
         result = []
         if not include_keys:
@@ -234,7 +247,12 @@ class CHKMap:
 
     @classmethod
     def from_dict(
-        klass, store, initial_value, maximum_size=0, key_width=1, search_key_func=None
+        cls,
+        store,
+        initial_value,
+        maximum_size: int = 0,
+        key_width: int = 1,
+        search_key_func: Optional[SearchKeyFunc] = None,
     ):
         """Create a CHKMap in store with initial_value as the content.
 
@@ -251,24 +269,29 @@ class CHKMap:
             multiple pages.
         :return: The root chk of the resulting CHKMap.
         """
-        root_key = klass._create_directly(
+        root_key = cls._create_directly(
             store,
             initial_value,
             maximum_size=maximum_size,
             key_width=key_width,
             search_key_func=search_key_func,
         )
-        if not isinstance(root_key, StaticTuple):
+        if not isinstance(root_key, tuple):
             raise AssertionError(
-                "we got a {} instead of a StaticTuple".format(type(root_key))
+                "we got a {} instead of a tuple".format(type(root_key))
             )
         return root_key
 
     @classmethod
     def _create_via_map(
-        klass, store, initial_value, maximum_size=0, key_width=1, search_key_func=None
+        cls,
+        store,
+        initial_value,
+        maximum_size: int = 0,
+        key_width: int = 1,
+        search_key_func: Optional[SearchKeyFunc] = None,
     ):
-        result = klass(store, None, search_key_func=search_key_func)
+        result = cls(store, None, search_key_func=search_key_func)
         result._root_node.set_maximum_size(maximum_size)
         result._root_node._key_width = key_width
         delta = []
@@ -279,13 +302,18 @@ class CHKMap:
 
     @classmethod
     def _create_directly(
-        klass, store, initial_value, maximum_size=0, key_width=1, search_key_func=None
+        cls,
+        store,
+        initial_value,
+        maximum_size: int = 0,
+        key_width: int = 1,
+        search_key_func: Optional[SearchKeyFunc] = None,
     ):
+        node: Node
         node = LeafNode(search_key_func=search_key_func)
         node.set_maximum_size(maximum_size)
         node._key_width = key_width
-        as_st = StaticTuple.from_sequence
-        node._items = {as_st(key): val for key, val in initial_value.items()}
+        node._items = {tuple(key): val for key, val in initial_value.items()}
         node._raw_size = sum(
             node._key_value_len(key, value) for key, value in node._items.items()
         )
@@ -531,32 +559,39 @@ class CHKMap:
                         process_node(node, path, basis, basis_pending)
         # print loop_counter
 
-    def iteritems(self, key_filter=None):
+    def iteritems(
+        self, key_filter: Optional[KeyFilter] = None
+    ) -> Iterator[tuple[Key, bytes]]:
         """Iterate over the entire CHKMap's contents."""
         self._ensure_root()
         if key_filter is not None:
-            as_st = StaticTuple.from_sequence
-            key_filter = [as_st(key) for key in key_filter]
+            key_filter = [tuple(key) for key in key_filter]
         return self._root_node.iteritems(self._store, key_filter=key_filter)
 
-    def key(self):
+    def key(self) -> Key:
         """Return the key for this map."""
-        if isinstance(self._root_node, StaticTuple):
+        if isinstance(self._root_node, tuple):
             return self._root_node
-        else:
+        elif isinstance(self._root_node, Node):
+            if self._root_node is None:
+                raise AssertionError("No root node")
             return self._root_node._key
+        else:
+            raise AssertionError(
+                "Invalid root node type: {!r}".format(type(self._root_node))
+            )
 
-    def __len__(self):
+    def __len__(self) -> int:
         self._ensure_root()
         return len(self._root_node)
 
-    def map(self, key, value):
+    def map(self, key: Key, value) -> None:
         """Map a key tuple to value.
 
         :param key: A key to map.
         :param value: The value to assign to key.
         """
-        key = StaticTuple.from_sequence(key)
+        key = tuple(key)
         # Need a root object.
         self._ensure_root()
         prefix, node_details = self._root_node.map(self._store, key, value)
@@ -574,15 +609,15 @@ class CHKMap:
     def _node_key(self, node):
         """Get the key for a node whether it's a tuple or node."""
         if isinstance(node, tuple):
-            node = StaticTuple.from_sequence(node)
-        if isinstance(node, StaticTuple):
             return node
-        else:
+        elif isinstance(node, Node):
             return node._key
+        else:
+            raise AssertionError("Invalid node type: {!r}".format(type(node)))
 
-    def unmap(self, key, check_remap=True):
+    def unmap(self, key: Key, check_remap=True) -> None:
         """Remove key from the map."""
-        key = StaticTuple.from_sequence(key)
+        key = tuple(key)
         self._ensure_root()
         if isinstance(self._root_node, InternalNode):
             unmapped = self._root_node.unmap(self._store, key, check_remap=check_remap)
@@ -590,7 +625,7 @@ class CHKMap:
             unmapped = self._root_node.unmap(self._store, key)
         self._root_node = unmapped
 
-    def _check_remap(self):
+    def _check_remap(self) -> None:
         """Check if nodes can be collapsed."""
         self._ensure_root()
         if isinstance(self._root_node, InternalNode):
@@ -601,7 +636,7 @@ class CHKMap:
 
         :return: The key of the root node.
         """
-        if isinstance(self._root_node, StaticTuple):
+        if isinstance(self._root_node, tuple):
             # Already saved.
             return self._root_node
         keys = list(self._root_node.serialise(self._store))
@@ -657,14 +692,16 @@ class Node:
             items_str,
         )
 
-    def key(self):
+    def key(self) -> Key:
+        """Return the key for this node."""
         return self._key
 
-    def __len__(self):
+    def __len__(self) -> int:
+        """Return the number of items in this node."""
         return self._len
 
     @property
-    def maximum_size(self):
+    def maximum_size(self) -> int:
         """What is the upper limit for adding references to a node."""
         return self._maximum_size
 
@@ -714,6 +751,40 @@ class Node:
                 return b""
         return common_prefix
 
+    def serialise(self, store) -> Iterator[Key]:
+        """Serialise the node into the store.
+
+        :param store: The store to serialise into.
+        :return: An iterable of keys that were written to the store.
+        """
+        raise NotImplementedError("serialise must be implemented in subclasses")
+
+    def iteritems(
+        self, store, key_filter: Optional[KeyFilter] = None
+    ) -> Iterator[tuple[Key, bytes]]:
+        """Iterate over items in the node.
+
+        :param key_filter: A filter to apply to the node. It should be a
+            list/set/dict or similar repeatedly iterable container.
+        """
+        raise NotImplementedError("iteritems must be implemented in subclasses")
+
+    def add_node(self, prefix: Key, node: "Node") -> None:
+        """Add a child node with prefix prefix, and node node.
+
+        :param prefix: The search key prefix for node.
+        :param node: The node being added.
+        """
+        raise NotImplementedError("add_node must be implemented in subclasses")
+
+    def map(self, store, key: Key, value) -> tuple[Key, list[tuple[Key, "Node"]]]:
+        """Map key to value."""
+        raise NotImplementedError("map must be implemented in subclasses")
+
+    def unmap(self, store, key: Key) -> "Node":
+        """Unmap key from the node."""
+        raise NotImplementedError("unmap must be implemented in subclasses")
+
 
 # Singleton indicating we have not computed _search_prefix yet
 _unknown = object()
@@ -782,13 +853,13 @@ class LeafNode(Node):
         )
 
     @classmethod
-    def deserialise(klass, bytes, key, search_key_func=None):
+    def deserialise(cls, bytes, key, search_key_func=None):
         """Deserialise bytes, with key key, into a LeafNode.
 
         :param bytes: The bytes of the node.
         :param key: The key that the serialised node has.
         """
-        key = expect_static_tuple(key)
+        key = tuple(key)
         return _deserialise_leaf_node(bytes, key, search_key_func=search_key_func)
 
     def iteritems(self, store, key_filter=None):
@@ -836,10 +907,10 @@ class LeafNode(Node):
             + 1
         )
 
-    def _search_key(self, key):
+    def _search_key(self, key: Key) -> bytes:
         return self._search_key_func(key)
 
-    def _map_no_split(self, key, value):
+    def _map_no_split(self, key: Key, value):
         """Map a key to a value.
 
         This assumes either the key does not already exist, or you have already
@@ -928,7 +999,7 @@ class LeafNode(Node):
                 result[prefix] = new_node
         return common_prefix, list(result.items())
 
-    def map(self, store, key, value):
+    def map(self, store, key: Key, value):
         """Map key to value."""
         if key in self._items:
             self._raw_size -= self._key_value_len(key, self._items[key])
@@ -941,7 +1012,9 @@ class LeafNode(Node):
                 raise AssertionError("{!r} must be known".format(self._search_prefix))
             return self._search_prefix, [(b"", self)]
 
-    _serialise_key = b"\x00".join
+    @staticmethod
+    def _serialise_key(key: Key) -> SerialisedKey:
+        return b"\x00".join(key)
 
     def serialise(self, store):
         """Serialise the LeafNode to store.
@@ -976,9 +1049,7 @@ class LeafNode(Node):
             lines.append(serialized[prefix_len:])
             lines.extend(value_lines)
         sha1, _, _ = store.add_lines((None,), (), lines)
-        self._key = StaticTuple(
-            b"sha1:" + sha1,
-        ).intern()
+        self._key = (b"sha1:" + sha1,)
         data = b"".join(lines)
         if len(data) != self._current_size():
             raise AssertionError("Invalid _current_size")
@@ -1064,7 +1135,7 @@ class InternalNode(Node):
         else:
             self._search_key_func = search_key_func
 
-    def add_node(self, prefix, node):
+    def add_node(self, prefix, node: "Node") -> None:
         """Add a child node with prefix prefix, and node node.
 
         :param prefix: The search key prefix for node.
@@ -1072,6 +1143,8 @@ class InternalNode(Node):
         """
         if self._search_prefix is None:
             raise AssertionError("_search_prefix should not be None")
+        if not isinstance(node, (tuple, Node)):
+            raise AssertionError("Invalid node type: {!r}".format(type(node)))
         if not prefix.startswith(self._search_prefix):
             raise AssertionError(
                 "prefixes mismatch: {} must start with {}".format(
@@ -1102,21 +1175,28 @@ class InternalNode(Node):
         )
 
     @classmethod
-    def deserialise(klass, bytes, key, search_key_func=None):
+    def deserialise(cls, bytes, key, search_key_func: Optional[SearchKeyFunc] = None):
         """Deserialise bytes to an InternalNode, with key key.
 
         :param bytes: The bytes of the node.
         :param key: The key that the serialised node has.
         :return: An InternalNode instance.
         """
-        key = expect_static_tuple(key)
+        key = tuple(key)
         return _deserialise_internal_node(bytes, key, search_key_func=search_key_func)
 
-    def iteritems(self, store, key_filter=None):
+    def iteritems(
+        self, store, key_filter: Optional[list[Key]] = None
+    ) -> Generator[tuple[Key, bytes]]:
         for node, node_filter in self._iter_nodes(store, key_filter=key_filter):
             yield from node.iteritems(store, key_filter=node_filter)
 
-    def _iter_nodes(self, store, key_filter=None, batch_size=None):
+    def _iter_nodes(
+        self,
+        store,
+        key_filter: Optional[KeyFilter] = None,
+        batch_size: Optional[int] = None,
+    ) -> Generator[tuple[Node, Optional[list[Key]]]]:
         """Iterate over node objects which match key_filter.
 
         :param store: A store to use for accessing content.
@@ -1131,17 +1211,19 @@ class InternalNode(Node):
         # Map from chk key ('sha1:...',) to (prefix, key_filter)
         # prefix is the key in self._items to use, key_filter is the key_filter
         # entries that would match this node
-        keys = {}
+        keys: dict[Key, tuple[SerialisedKey, Optional[list[Key]]]] = {}
         shortcut = False
         if key_filter is None:
             # yielding all nodes, yield whatever we have, and queue up a read
             # for whatever we are missing
             shortcut = True
             for prefix, node in self._items.items():
-                if node.__class__ is StaticTuple:
+                if isinstance(node, tuple):
                     keys[node] = (prefix, None)
-                else:
+                elif isinstance(node, Node):
                     yield node, None
+                else:
+                    raise AssertionError("Invalid node type: {!r}".format(type(node)))
         elif len(key_filter) == 1:
             # Technically, this path could also be handled by the first check
             # in 'self._node_width' in length_filters. However, we can handle
@@ -1173,18 +1255,23 @@ class InternalNode(Node):
                     # A given key can only match 1 child node, if it isn't
                     # there, then we can just return nothing
                     return
-                if node.__class__ is StaticTuple:
+                if isinstance(node, tuple):
                     keys[node] = (search_prefix, [key])
-                else:
+                elif isinstance(node, Node):
                     # This is loaded, and the only thing that can match,
                     # return
                     yield node, [key]
                     return
+                else:
+                    raise AssertionError("Invalid node type: {!r}".format(type(node)))
         if not shortcut:
             # First, convert all keys into a list of search prefixes
             # Aggregate common prefixes, and track the keys they come from
-            prefix_to_keys = {}
-            length_filters = {}
+            prefix_to_keys: dict[SerialisedKey, list[Key]] = {}
+            length_filters: dict[int, set[SerialisedKey]] = {}
+            node_key_filter: Optional[list[Key]] = None
+            if key_filter is None:
+                raise AssertionError("key_filter must not be None")
             for key in key_filter:
                 search_prefix = self._search_prefix_filter(key)
                 length_filter = length_filters.setdefault(len(search_prefix), set())
@@ -1204,10 +1291,14 @@ class InternalNode(Node):
                         # We can ignore this one
                         continue
                     node_key_filter = prefix_to_keys[search_prefix]
-                    if node.__class__ is StaticTuple:
+                    if isinstance(node, tuple):
                         keys[node] = (search_prefix, node_key_filter)
-                    else:
+                    elif isinstance(node, Node):
                         yield node, node_key_filter
+                    else:
+                        raise AssertionError(
+                            "Invalid node type: {!r}".format(type(node))
+                        )
             else:
                 # The slow way. We walk every item in self._items, and check to
                 # see if there are any matches
@@ -1219,10 +1310,14 @@ class InternalNode(Node):
                         if sub_prefix in length_filter:
                             node_key_filter.extend(prefix_to_keys[sub_prefix])
                     if node_key_filter:  # this key matched something, yield it
-                        if node.__class__ is StaticTuple:
+                        if isinstance(node, tuple):
                             keys[node] = (prefix, node_key_filter)
-                        else:
+                        elif isinstance(node, Node):
                             yield node, node_key_filter
+                        else:
+                            raise AssertionError(
+                                "Invalid node type: {!r}".format(type(node))
+                            )
         if keys:
             # Look in the page cache for some more bytes
             found_keys = set()
@@ -1236,6 +1331,10 @@ class InternalNode(Node):
                         bytes, key, search_key_func=self._search_key_func
                     )
                     prefix, node_key_filter = keys[key]
+                    if not isinstance(node, Node):
+                        raise AssertionError(
+                            "Invalid node type: {!r}".format(type(node))
+                        )
                     self._items[prefix] = node
                     found_keys.add(key)
                     yield node, node_key_filter
@@ -1260,6 +1359,10 @@ class InternalNode(Node):
                     )
                     prefix, node_key_filter = keys[record.key]
                     node_and_filters.append((node, node_key_filter))
+                    if not isinstance(node, Node):
+                        raise AssertionError(
+                            "Invalid node type: {!r}".format(type(node))
+                        )
                     self._items[prefix] = node
                     _get_cache()[record.key] = bytes
                 yield from node_and_filters
@@ -1358,14 +1461,19 @@ class InternalNode(Node):
         :return: An iterable of the keys inserted by this operation.
         """
         for node in self._items.values():
-            if isinstance(node, StaticTuple):
+            if isinstance(node, tuple):
                 # Never deserialised.
                 continue
-            if node._key is not None:
-                # Never altered
-                continue
-            for key in node.serialise(store):
-                yield key
+            elif isinstance(node, Node):
+                if node._key is not None:
+                    # Never altered
+                    continue
+                for key in node.serialise(store):
+                    yield key
+            else:
+                raise AssertionError(
+                    f"InternalNode._items should only contain tuples or Nodes, not {node.__class__}"
+                )
         lines = [b"chknode:\n"]
         lines.append(b"%d\n" % self._maximum_size)
         lines.append(b"%d\n" % self._key_width)
@@ -1375,10 +1483,14 @@ class InternalNode(Node):
         lines.append(b"%s\n" % (self._search_prefix,))
         prefix_len = len(self._search_prefix)
         for prefix, node in sorted(self._items.items()):
-            if isinstance(node, StaticTuple):
+            if isinstance(node, tuple):
                 key = node[0]
-            else:
+            elif isinstance(node, Node):
                 key = node._key[0]
+            else:
+                raise AssertionError(
+                    f"InternalNode._items should only contain tuples or Nodes, not {node.__class__}"
+                )
             serialised = b"%s\x00%s\n" % (prefix, key)
             if not serialised.startswith(self._search_prefix):
                 raise AssertionError(
@@ -1388,13 +1500,11 @@ class InternalNode(Node):
                 )
             lines.append(serialised[prefix_len:])
         sha1, _, _ = store.add_lines((None,), (), lines)
-        self._key = StaticTuple(
-            b"sha1:" + sha1,
-        ).intern()
+        self._key = (b"sha1:" + sha1,)
         _get_cache()[self._key] = b"".join(lines)
         yield self._key
 
-    def _search_key(self, key):
+    def _search_key(self, key: Key) -> SerialisedKey:
         """Return the serialised key for key in this node."""
         # search keys are fixed width. All will be self._node_width wide, so we
         # pad as necessary.
@@ -1402,11 +1512,11 @@ class InternalNode(Node):
             : self._node_width
         ]
 
-    def _search_prefix_filter(self, key):
+    def _search_prefix_filter(self, key: Key) -> SerialisedKey:
         """Serialise key for use as a prefix filter in iteritems."""
         return self._search_key_func(key)[: self._node_width]
 
-    def _split(self, offset):
+    def _split(self, offset: int) -> Iterator[tuple[SerialisedKey, Node]]:
         """Split this node into smaller nodes starting at offset.
 
         :param offset: The offset to start the new child nodes at.
@@ -1414,19 +1524,23 @@ class InternalNode(Node):
             prefix for reaching node.
         """
         if offset >= self._node_width:
-            for node in valueview(self._items):
+            for node in self._items.values():
                 yield from node._split(offset)
 
-    def refs(self):
+    def refs(self) -> list[tuple[SerialisedKey, Key]]:
         """Return the references to other CHK's held by this node."""
         if self._key is None:
             raise AssertionError("unserialised nodes have no refs.")
         refs = []
         for value in self._items.values():
-            if isinstance(value, StaticTuple):
+            if isinstance(value, tuple):
                 refs.append(value)
-            else:
+            elif isinstance(value, Node):
                 refs.append(value.key())
+            else:
+                raise AssertionError(
+                    f"InternalNode._items should only contain tuples or Nodes, not {value.__class__}"
+                )
         return refs
 
     def _compute_search_prefix(self, extra_key=None):
@@ -1438,7 +1552,7 @@ class InternalNode(Node):
         self._search_prefix = self.common_prefix_for_keys(self._items)
         return self._search_prefix
 
-    def unmap(self, store, key, check_remap=True):
+    def unmap(self, store, key: Key, check_remap: bool = True) -> Node:
         """Remove key from this node and its children."""
         if not len(self._items):
             raise AssertionError("can't unmap in an empty InternalNode.")
@@ -1448,6 +1562,7 @@ class InternalNode(Node):
         else:
             raise KeyError(key)
         self._len -= 1
+        unmapped: Optional[Node]
         unmapped = child.unmap(store, key)
         self._key = None
         search_key = self._search_key(key)
@@ -1468,7 +1583,7 @@ class InternalNode(Node):
         else:
             return self
 
-    def _check_remap(self, store):
+    def _check_remap(self, store) -> "Node":
         """Check if all keys contained by children fit in a single LeafNode.
 
         :param store: A store to use for reading more nodes
@@ -1816,8 +1931,8 @@ def _check_key(key):
     This generally shouldn't be used in production code, but it can be helpful
     to debug problems.
     """
-    if not isinstance(key, StaticTuple):
-        raise TypeError("key {!r} is not StaticTuple but {}".format(key, type(key)))
+    if not isinstance(key, tuple):
+        raise TypeError("key {!r} is not tuple but {}".format(key, type(key)))
     if len(key) != 1:
         raise ValueError(f"key {key!r} should have length 1, not {len(key)}")
     if not isinstance(key[0], str):
