@@ -39,10 +39,10 @@ class DoErrorRequest(request.SmartServerRequest):
 
 
 class DoUnexpectedErrorRequest(request.SmartServerRequest):
-    """A request that encounters a generic error in self.do()"""
+    """A request that encounters a generic error in self.do()."""
 
     def do(self):
-        dict()[1]
+        {}[1]
 
 
 class ChunkErrorRequest(request.SmartServerRequest):
@@ -130,7 +130,7 @@ class TestSmartRequest(TestCase):
         if unclassified_requests:
             self.fail(
                 "These requests were not categorized as safe/unsafe"
-                " to retry: %s" % (unclassified_requests,)
+                " to retry: {}".format(unclassified_requests)
             )
 
 
