@@ -14,17 +14,18 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-"""Tests for InventoryWorkingTree"""
+"""Tests for InventoryWorkingTree."""
 
 from ..workingtree import InventoryModified
 from . import TestCase
 
 
 class ErrorTests(TestCase):
-
     def test_inventory_modified(self):
         error = InventoryModified("a tree to be repred")
-        self.assertEqualDiff("The current inventory for the tree 'a tree to "
-                             "be repred' has been modified, so a clean inventory cannot be "
-                             "read without data loss.",
-                             str(error))
+        self.assertEqualDiff(
+            "The current inventory for the tree 'a tree to "
+            "be repred' has been modified, so a clean inventory cannot be "
+            "read without data loss.",
+            str(error),
+        )
