@@ -14,8 +14,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from __future__ import absolute_import
-
 from . import xml8
 
 
@@ -27,9 +25,9 @@ class Serializer_v6(xml8.Serializer_v8):
     converted from format 5 or 7 without updating the sha1.
     """
 
-    format_num = b'6'
+    format_num = b"6"
     # Format 6 & 7 reported their revision format as 5.
-    revision_format_num = b'5'
+    revision_format_num = b"5"
 
 
 serializer_v6 = Serializer_v6()
