@@ -14,7 +14,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-"""Counted lock class"""
+"""Counted lock class."""
 
 from . import errors
 
@@ -35,8 +35,7 @@ class CountedLock:
         self._lock_count = 0
 
     def __repr__(self):
-        return "{}({!r})".format(self.__class__.__name__,
-                           self._real_lock)
+        return "{}({!r})".format(self.__class__.__name__, self._real_lock)
 
     def break_lock(self):
         self._real_lock.break_lock()
@@ -70,7 +69,7 @@ class CountedLock:
         else:
             self._real_lock.lock_read()
             self._lock_count = 1
-            self._lock_mode = 'r'
+            self._lock_mode = "r"
 
     def lock_write(self, token=None):
         """Acquire the lock in write mode.
@@ -85,10 +84,10 @@ class CountedLock:
         """
         if self._lock_count == 0:
             self._token = self._real_lock.lock_write(token=token)
-            self._lock_mode = 'w'
+            self._lock_mode = "w"
             self._lock_count += 1
             return self._token
-        elif self._lock_mode != 'w':
+        elif self._lock_mode != "w":
             raise errors.ReadOnlyError(self)
         else:
             self._real_lock.validate_token(token)
