@@ -14,12 +14,12 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-"""Code to estimate the entropy of content"""
+"""Code to estimate the entropy of content."""
 
 import zlib
 
 
-class ZLibEstimator(object):
+class ZLibEstimator:
     """Uses zlib.compressobj to estimate compressed size."""
 
     def __init__(self, target_size, min_compression=2.0):
@@ -50,8 +50,9 @@ class ZLibEstimator(object):
         self._unflushed_size_added = 0
         # So far we've read X uncompressed bytes, and written Y compressed
         # bytes. We should have a decent estimate of the final compression.
-        self._estimated_compression = (float(self._uncompressed_size_added)
-                                       / self._compressed_size_added)
+        self._estimated_compression = (
+            float(self._uncompressed_size_added) / self._compressed_size_added
+        )
 
     def full(self):
         """Have we reached the target size?"""
@@ -59,8 +60,7 @@ class ZLibEstimator(object):
             remaining_size = self._target_size - self._compressed_size_added
             # Estimate how much compressed content the unflushed data will
             # consume
-            est_z_size = (self._unflushed_size_added /
-                          self._estimated_compression)
+            est_z_size = self._unflushed_size_added / self._estimated_compression
             if est_z_size >= remaining_size:
                 # We estimate we are close to remaining
                 z_size = len(self._compressor.flush(zlib.Z_SYNC_FLUSH))
