@@ -17,7 +17,7 @@
 """A simple first-in-first-out (FIFO) cache."""
 
 from collections import deque
-from typing import Any, Callable, Deque, Dict
+from typing import Any, Callable
 
 
 class FIFOCache(dict):
@@ -29,10 +29,11 @@ class FIFOCache(dict):
         if after_cleanup_count is None:
             self._after_cleanup_count = self._max_cache * 8 // 10
         else:
-            self._after_cleanup_count = min(after_cleanup_count,
-                                            self._max_cache)
-        self._cleanup: Dict[Any, Callable[[], None]] = {}  # map to cleanup functions when items are removed
-        self._queue: Deque[Any] = deque()  # Track when things are accessed
+            self._after_cleanup_count = min(after_cleanup_count, self._max_cache)
+        self._cleanup: dict[
+            Any, Callable[[], None]
+        ] = {}  # map to cleanup functions when items are removed
+        self._queue: deque[Any] = deque()  # Track when things are accessed
 
     def __setitem__(self, key, value):
         """Add a value to the cache, there will be no cleanup function."""
@@ -79,9 +80,10 @@ class FIFOCache(dict):
         while len(self) > self._after_cleanup_count:
             self._remove_oldest()
         if len(self._queue) != len(self):
-            raise AssertionError('The length of the queue should always equal'
-                                 ' the length of the dict. %s != %s'
-                                 % (len(self._queue), len(self)))
+            raise AssertionError(
+                "The length of the queue should always equal"
+                " the length of the dict. {} != {}".format(len(self._queue), len(self))
+            )
 
     def clear(self):
         """Clear out all of the cache."""
@@ -137,14 +139,14 @@ class FIFOCache(dict):
         raise NotImplementedError(self.popitem)
 
     def setdefault(self, key, defaultval=None):
-        """similar to dict.setdefault"""
+        """Similar to dict.setdefault."""
         if key in self:
             return self[key]
         self[key] = defaultval
         return defaultval
 
     def update(self, *args, **kwargs):
-        """Similar to dict.update()"""
+        """Similar to dict.update()."""
         if len(args) == 1:
             arg = args[0]
             if isinstance(arg, dict):
@@ -154,8 +156,7 @@ class FIFOCache(dict):
                 for key, val in args[0]:
                     self.add(key, val)
         elif len(args) > 1:
-            raise TypeError('update expected at most 1 argument, got %d'
-                            % len(args))
+            raise TypeError(f"update expected at most 1 argument, got {len(args)}")
         if kwargs:
             for key in kwargs:
                 self.add(key, kwargs[key])
@@ -168,8 +169,9 @@ class FIFOSizeCache(FIFOCache):
     it restricts the cache to be cleaned based on the size of the data.
     """
 
-    def __init__(self, max_size=1024 * 1024, after_cleanup_size=None,
-                 compute_size=None):
+    def __init__(
+        self, max_size=1024 * 1024, after_cleanup_size=None, compute_size=None
+    ):
         """Create a new FIFOSizeCache.
 
         :param max_size: The max number of bytes to store before we start
