@@ -18,40 +18,21 @@
 
 import sys
 
-from dulwich.object_store import (
-    MissingObjectFinder,
-    peel_sha,
-)
+from dulwich.object_store import MissingObjectFinder, peel_sha
 from dulwich.protocol import Protocol
 from dulwich.server import (
-    TCPGitServer,
     Backend,
     BackendRepo,
     ReceivePackHandler,
+    TCPGitServer,
     UploadPackHandler,
-    )
+)
 
-
-from .. import (
-    errors,
-    trace,
-    )
-
-from ..controldir import (
-    ControlDir,
-    )
-
-from .mapping import (
-    default_mapping,
-    decode_git_path,
-    )
-from .object_store import (
-    BazaarObjectStore,
-    get_object_store,
-    )
-from .refs import (
-    get_refs_container,
-    )
+from .. import errors, trace
+from ..controldir import ControlDir
+from .mapping import decode_git_path, default_mapping
+from .object_store import BazaarObjectStore, get_object_store
+from .refs import get_refs_container
 
 
 class BzrBackend(Backend):
@@ -64,12 +45,11 @@ class BzrBackend(Backend):
     def open_repository(self, path):
         # FIXME: More secure path sanitization
         transport = self.transport.clone(decode_git_path(path).lstrip("/"))
-        trace.mutter('client opens %r: %r', path, transport)
+        trace.mutter("client opens %r: %r", path, transport)
         return BzrBackendRepo(transport, self.mapping)
 
 
 class BzrBackendRepo(BackendRepo):
-
     def __init__(self, transport, mapping):
         self.mapping = mapping
         self.repo_dir = ControlDir.open_from_transport(transport)
@@ -87,38 +67,44 @@ class BzrBackendRepo(BackendRepo):
             return cached
         return peel_sha(self.object_store, self.refs[name])[1].id
 
-    def find_missing_objects(self, determine_wants, graph_walker, progress,
-                      get_tagged=None):
-        """Yield git objects to send to client """
+    def find_missing_objects(
+        self, determine_wants, graph_walker, progress, get_tagged=None
+    ):
+        """Yield git objects to send to client."""
         with self.object_store.lock_read():
             wants = determine_wants(self.get_refs())
             have = self.object_store.find_common_revisions(graph_walker)
             if wants is None:
                 return
-            shallows = getattr(graph_walker, 'shallow', frozenset())
+            shallows = getattr(graph_walker, "shallow", frozenset())
             if isinstance(self.object_store, BazaarObjectStore):
                 return self.object_store.find_missing_objects(
-                    have, wants, shallow=shallows,
-                    progress=progress, get_tagged=get_tagged, lossy=True)
+                    have,
+                    wants,
+                    shallow=shallows,
+                    progress=progress,
+                    get_tagged=get_tagged,
+                    lossy=True,
+                )
             else:
                 return MissingObjectFinder(
-                    self.object_store,
-                    have, wants, shallow=shallows, progress=progress)
+                    self.object_store, have, wants, shallow=shallows, progress=progress
+                )
 
 
 class BzrTCPGitServer(TCPGitServer):
-
     def handle_error(self, request, client_address):
         trace.log_exception_quietly()
-        trace.warning('Exception happened during processing of request '
-                      'from %s', client_address)
+        trace.warning(
+            "Exception happened during processing of request from %s", client_address
+        )
 
 
 def serve_git(transport, host=None, port=None, inet=False, timeout=None):
     backend = BzrBackend(transport)
 
     if host is None:
-        host = 'localhost'
+        host = "localhost"
     if port:
         server = BzrTCPGitServer(backend, host, port)
     else:
@@ -127,9 +113,10 @@ def serve_git(transport, host=None, port=None, inet=False, timeout=None):
 
 
 def git_http_hook(branch, method, path):
-    from dulwich.web import HTTPGitApplication, HTTPGitRequest, DEFAULT_HANDLERS
+    from dulwich.web import DEFAULT_HANDLERS, HTTPGitApplication, HTTPGitRequest
+
     handler = None
-    for (smethod, spath) in HTTPGitApplication.services:
+    for smethod, spath in HTTPGitApplication.services:
         if smethod != method:
             continue
         mat = spath.search(path)
@@ -141,9 +128,11 @@ def git_http_hook(branch, method, path):
     backend = BzrBackend(branch.user_transport)
 
     def git_call(environ, start_response):
-        req = HTTPGitRequest(environ, start_response, dumb=False,
-                             handlers=DEFAULT_HANDLERS)
+        req = HTTPGitRequest(
+            environ, start_response, dumb=False, handlers=DEFAULT_HANDLERS
+        )
         return handler(req, backend, mat)
+
     return git_call
 
 
@@ -159,9 +148,11 @@ def serve_command(handler_cls, backend, inf=sys.stdin, outf=sys.stdout):
     :param outf: File-like object to write to, defaults to standard output.
     :return: Exit code for use with sys.exit. 0 on success, 1 on failure.
     """
+
     def send_fn(data):
         outf.write(data)
         outf.flush()
+
     proto = Protocol(inf.read, send_fn)
     handler = handler_cls(backend, ["/"], proto)
     # FIXME: Catch exceptions and write a single-line summary to outf.
@@ -171,15 +162,13 @@ def serve_command(handler_cls, backend, inf=sys.stdin, outf=sys.stdout):
 
 def serve_git_receive_pack(transport, host=None, port=None, inet=False):
     if not inet:
-        raise errors.CommandError(
-            "git-receive-pack only works in inetd mode")
+        raise errors.CommandError("git-receive-pack only works in inetd mode")
     backend = BzrBackend(transport)
     sys.exit(serve_command(ReceivePackHandler, backend=backend))
 
 
 def serve_git_upload_pack(transport, host=None, port=None, inet=False):
     if not inet:
-        raise errors.CommandError(
-            "git-receive-pack only works in inetd mode")
+        raise errors.CommandError("git-receive-pack only works in inetd mode")
     backend = BzrBackend(transport)
     sys.exit(serve_command(UploadPackHandler, backend=backend))
