@@ -194,7 +194,7 @@ class RepositoryFetchTests:
         os.chdir("d")
         bb = GitBranchBuilder()
         bb.set_file("foobar", b"foo\nbar\n", False)
-        mark1 = bb.commit(b"Somebody <somebody@someorg.org>", b"mymsg")
+        bb.commit(b"Somebody <somebody@someorg.org>", b"mymsg")
         bb.set_file("foobar", b"foo\nbar\n", True)
         mark2 = bb.commit(b"Somebody <somebody@someorg.org>", b"mymsg")
         gitsha2 = bb.finish()[mark2]
@@ -208,7 +208,7 @@ class RepositoryFetchTests:
         self.assertEqual(revid, tree.get_file_revision("foobar"))
 
     def test_into_stacked_on(self):
-        r = self.make_git_repo("d")
+        self.make_git_repo("d")
         os.chdir("d")
         bb = GitBranchBuilder()
         bb.set_file("foobar", b"foo\n", False)
@@ -321,7 +321,7 @@ class ImportObjects(TestCaseWithTransport):
 
         blob = Blob.from_string(b"bar")
         objs = {"blobname": blob}
-        ret = import_git_blob(
+        import_git_blob(
             self._texts,
             self._mapping,
             b"bla",
