@@ -16,46 +16,38 @@
 
 """Tests for mapping."""
 
-from ...revision import (
-    Revision,
-    )
-
-from dulwich.objects import (
-    Blob,
-    Commit,
-    Tag,
-    parse_timezone,
-    )
-from dulwich.tests.utils import (
-    make_object,
-    )
+from dulwich.objects import Blob, Commit, Tag, parse_timezone
+from dulwich.tests.utils import make_object
 
+from ...revision import Revision
 from .. import tests
 from ..mapping import (
     BzrGitMappingv1,
+    UnknownCommitEncoding,
+    UnknownCommitExtra,
+    UnknownMercurialCommitExtra,
     escape_file_id,
     fix_person_identifier,
     unescape_file_id,
-    UnknownCommitExtra,
-    UnknownCommitEncoding,
-    UnknownMercurialCommitExtra,
-    )
+)
 
 
 class TestRevidConversionV1(tests.TestCase):
-
     def test_simple_git_to_bzr_revision_id(self):
-        self.assertEqual(b"git-v1:"
-                         b"c6a4d8f1fa4ac650748e647c4b1b368f589a7356",
-                         BzrGitMappingv1().revision_id_foreign_to_bzr(
-                             b"c6a4d8f1fa4ac650748e647c4b1b368f589a7356"))
+        self.assertEqual(
+            b"git-v1:c6a4d8f1fa4ac650748e647c4b1b368f589a7356",
+            BzrGitMappingv1().revision_id_foreign_to_bzr(
+                b"c6a4d8f1fa4ac650748e647c4b1b368f589a7356"
+            ),
+        )
 
     def test_simple_bzr_to_git_revision_id(self):
-        self.assertEqual((b"c6a4d8f1fa4ac650748e647c4b1b368f589a7356",
-                          BzrGitMappingv1()),
-                         BzrGitMappingv1().revision_id_bzr_to_foreign(
-            b"git-v1:"
-            b"c6a4d8f1fa4ac650748e647c4b1b368f589a7356"))
+        self.assertEqual(
+            (b"c6a4d8f1fa4ac650748e647c4b1b368f589a7356", BzrGitMappingv1()),
+            BzrGitMappingv1().revision_id_bzr_to_foreign(
+                b"git-v1:c6a4d8f1fa4ac650748e647c4b1b368f589a7356"
+            ),
+        )
 
     def test_is_control_file(self):
         mapping = BzrGitMappingv1()
@@ -71,7 +63,6 @@ class TestRevidConversionV1(tests.TestCase):
 
 
 class FileidTests(tests.TestCase):
-
     def test_escape_space(self):
         self.assertEqual(b"bla_s", escape_file_id(b"bla "))
 
@@ -95,7 +86,6 @@ class FileidTests(tests.TestCase):
 
 
 class TestImportCommit(tests.TestCase):
-
     def test_commit(self):
         c = Commit()
         c.tree = b"cc9462f7f8263ef5adfbeff2fb936bb36b504cba"
@@ -108,18 +98,36 @@ class TestImportCommit(tests.TestCase):
         c.author = b"Author"
         mapping = BzrGitMappingv1()
         rev, roundtrip_revid, verifiers = mapping.import_commit(
-            c, mapping.revision_id_foreign_to_bzr)
+            c, mapping.revision_id_foreign_to_bzr
+        )
         self.assertEqual(None, roundtrip_revid)
         self.assertEqual({}, verifiers)
         self.assertEqual("Some message", rev.message)
         self.assertEqual("Committer", rev.committer)
-        self.assertEqual("Author", rev.properties['author'])
+        self.assertEqual("Author", rev.properties["author"])
         self.assertEqual(300, rev.timezone)
         self.assertEqual([], rev.parent_ids)
-        self.assertEqual("5", rev.properties['author-timestamp'])
-        self.assertEqual("180", rev.properties['author-timezone'])
+        self.assertEqual("5", rev.properties["author-timestamp"])
+        self.assertEqual("180", rev.properties["author-timezone"])
         self.assertEqual(b"git-v1:" + c.id, rev.revision_id)
 
+    def test_missing_message(self):
+        c = Commit()
+        c.tree = b"cc9462f7f8263ef5adfbeff2fb936bb36b504cba"
+        c.message = None
+        c.committer = b"Committer"
+        c.commit_time = 4
+        c.author_time = 5
+        c.commit_timezone = 60 * 5
+        c.author_timezone = 60 * 3
+        c.author = b"Author"
+        c.id  # noqa: B018
+        mapping = BzrGitMappingv1()
+        rev, roundtrip_revid, verifiers = mapping.import_commit(
+            c, mapping.revision_id_foreign_to_bzr
+        )
+        self.assertIs(rev.message, None)
+
     def test_unknown_encoding(self):
         c = Commit()
         c.tree = b"cc9462f7f8263ef5adfbeff2fb936bb36b504cba"
@@ -133,8 +141,11 @@ class TestImportCommit(tests.TestCase):
         c.encoding = b"Unknown"
         mapping = BzrGitMappingv1()
         e = self.assertRaises(
-            UnknownCommitEncoding, mapping.import_commit,
-            c, mapping.revision_id_foreign_to_bzr)
+            UnknownCommitEncoding,
+            mapping.import_commit,
+            c,
+            mapping.revision_id_foreign_to_bzr,
+        )
         self.assertEqual(e.encoding, "Unknown")
 
     def test_explicit_encoding(self):
@@ -150,10 +161,11 @@ class TestImportCommit(tests.TestCase):
         c.encoding = b"iso8859-1"
         mapping = BzrGitMappingv1()
         rev, roundtrip_revid, verifiers = mapping.import_commit(
-            c, mapping.revision_id_foreign_to_bzr)
+            c, mapping.revision_id_foreign_to_bzr
+        )
         self.assertEqual(None, roundtrip_revid)
         self.assertEqual({}, verifiers)
-        self.assertEqual("Authér", rev.properties['author'])
+        self.assertEqual("Authér", rev.properties["author"])
         self.assertEqual("iso8859-1", rev.properties["git-explicit-encoding"])
         self.assertTrue("git-implicit-encoding" not in rev.properties)
 
@@ -170,10 +182,11 @@ class TestImportCommit(tests.TestCase):
         c.encoding = b"false"
         mapping = BzrGitMappingv1()
         rev, roundtrip_revid, verifiers = mapping.import_commit(
-            c, mapping.revision_id_foreign_to_bzr)
+            c, mapping.revision_id_foreign_to_bzr
+        )
         self.assertEqual(None, roundtrip_revid)
         self.assertEqual({}, verifiers)
-        self.assertEqual("Authér", rev.properties['author'])
+        self.assertEqual("Authér", rev.properties["author"])
         self.assertEqual("false", rev.properties["git-explicit-encoding"])
         self.assertTrue("git-implicit-encoding" not in rev.properties)
 
@@ -189,10 +202,11 @@ class TestImportCommit(tests.TestCase):
         c.author = "Authér".encode("latin1")
         mapping = BzrGitMappingv1()
         rev, roundtrip_revid, verifiers = mapping.import_commit(
-            c, mapping.revision_id_foreign_to_bzr)
+            c, mapping.revision_id_foreign_to_bzr
+        )
         self.assertEqual(None, roundtrip_revid)
         self.assertEqual({}, verifiers)
-        self.assertEqual("Authér", rev.properties['author'])
+        self.assertEqual("Authér", rev.properties["author"])
         self.assertEqual("latin1", rev.properties["git-implicit-encoding"])
         self.assertTrue("git-explicit-encoding" not in rev.properties)
 
@@ -208,10 +222,11 @@ class TestImportCommit(tests.TestCase):
         c.author = "Authér".encode()
         mapping = BzrGitMappingv1()
         rev, roundtrip_revid, verifiers = mapping.import_commit(
-            c, mapping.revision_id_foreign_to_bzr)
+            c, mapping.revision_id_foreign_to_bzr
+        )
         self.assertEqual(None, roundtrip_revid)
         self.assertEqual({}, verifiers)
-        self.assertEqual("Authér", rev.properties['author'])
+        self.assertEqual("Authér", rev.properties["author"])
         self.assertTrue("git-explicit-encoding" not in rev.properties)
         self.assertTrue("git-implicit-encoding" not in rev.properties)
 
@@ -227,8 +242,12 @@ class TestImportCommit(tests.TestCase):
         c.author = b"Author"
         c._extra.append((b"iamextra", b"foo"))
         mapping = BzrGitMappingv1()
-        self.assertRaises(UnknownCommitExtra, mapping.import_commit, c,
-                          mapping.revision_id_foreign_to_bzr)
+        self.assertRaises(
+            UnknownCommitExtra,
+            mapping.import_commit,
+            c,
+            mapping.revision_id_foreign_to_bzr,
+        )
         mapping.import_commit(c, mapping.revision_id_foreign_to_bzr, strict=False)
 
     def test_mergetag(self):
@@ -241,18 +260,23 @@ class TestImportCommit(tests.TestCase):
         c.commit_timezone = 60 * 5
         c.author_timezone = 60 * 3
         c.author = b"Author"
-        tag = make_object(Tag,
-                          tagger=b'Jelmer Vernooij <jelmer@samba.org>',
-                          name=b'0.1', message=None,
-                          object=(
-                              Blob, b'd80c186a03f423a81b39df39dc87fd269736ca86'),
-                          tag_time=423423423, tag_timezone=0)
+        tag = make_object(
+            Tag,
+            tagger=b"Jelmer Vernooij <jelmer@samba.org>",
+            name=b"0.1",
+            message=None,
+            object=(Blob, b"d80c186a03f423a81b39df39dc87fd269736ca86"),
+            tag_time=423423423,
+            tag_timezone=0,
+        )
         c.mergetag = [tag]
         mapping = BzrGitMappingv1()
         rev, roundtrip_revid, verifiers = mapping.import_commit(
-            c, mapping.revision_id_foreign_to_bzr)
+            c, mapping.revision_id_foreign_to_bzr
+        )
         self.assertEqual(
-            rev.properties['git-mergetag-0'].encode('utf-8'), tag.as_raw_string())
+            rev.properties["git-mergetag-0"].encode("utf-8"), tag.as_raw_string()
+        )
 
     def test_unknown_hg_fields(self):
         c = Commit()
@@ -268,12 +292,14 @@ class TestImportCommit(tests.TestCase):
         mapping = BzrGitMappingv1()
         self.assertRaises(
             UnknownMercurialCommitExtra,
-            mapping.import_commit, c, mapping.revision_id_foreign_to_bzr)
-        mapping.import_commit(
-            c, mapping.revision_id_foreign_to_bzr, strict=False)
+            mapping.import_commit,
+            c,
+            mapping.revision_id_foreign_to_bzr,
+        )
+        mapping.import_commit(c, mapping.revision_id_foreign_to_bzr, strict=False)
         self.assertEqual(
-            mapping.revision_id_foreign_to_bzr(c.id),
-            mapping.get_revision_id(c))
+            mapping.revision_id_foreign_to_bzr(c.id), mapping.get_revision_id(c)
+        )
 
     def test_invalid_utf8(self):
         c = Commit()
@@ -287,12 +313,11 @@ class TestImportCommit(tests.TestCase):
         c.author = b"Author"
         mapping = BzrGitMappingv1()
         self.assertEqual(
-            mapping.revision_id_foreign_to_bzr(c.id),
-            mapping.get_revision_id(c))
+            mapping.revision_id_foreign_to_bzr(c.id), mapping.get_revision_id(c)
+        )
 
 
 class RoundtripRevisionsFromBazaar(tests.TestCase):
-
     def setUp(self):
         super().setUp()
         self.mapping = BzrGitMappingv1()
@@ -300,12 +325,15 @@ class RoundtripRevisionsFromBazaar(tests.TestCase):
         self._lookup_parent = self._parent_map.__getitem__
 
     def assertRoundtripRevision(self, orig_rev):
-        commit = self.mapping.export_commit(orig_rev, b"mysha",
-                                            self._lookup_parent, True, b"testamentsha")
+        commit = self.mapping.export_commit(
+            orig_rev, b"mysha", self._lookup_parent, True, b"testamentsha"
+        )
         rev, roundtrip_revid, verifiers = self.mapping.import_commit(
-            commit, self.mapping.revision_id_foreign_to_bzr, strict=True)
-        self.assertEqual(rev.revision_id,
-                         self.mapping.revision_id_foreign_to_bzr(commit.id))
+            commit, self.mapping.revision_id_foreign_to_bzr, strict=True
+        )
+        self.assertEqual(
+            rev.revision_id, self.mapping.revision_id_foreign_to_bzr(commit.id)
+        )
         if self.mapping.roundtripping:
             self.assertEqual({"testament3-sha1": b"testamentsha"}, verifiers)
             self.assertEqual(orig_rev.revision_id, roundtrip_revid)
@@ -320,8 +348,11 @@ class RoundtripRevisionsFromBazaar(tests.TestCase):
         return commit
 
     def test_simple_commit(self):
-        r = Revision(self.mapping.revision_id_foreign_to_bzr(
-            b"edf99e6c56495c620f20d5dacff9859ff7119261"))
+        r = Revision(
+            self.mapping.revision_id_foreign_to_bzr(
+                b"edf99e6c56495c620f20d5dacff9859ff7119261"
+            )
+        )
         r.message = "MyCommitMessage"
         r.parent_ids = []
         r.committer = "Jelmer Vernooij <jelmer@apache.org>"
@@ -365,32 +396,29 @@ class RoundtripRevisionsFromBazaar(tests.TestCase):
         r.message = "MyCommitMessage"
         r.parent_ids = []
         r.properties = {
-            "authors":
-                "Jelmer Vernooij <jelmer@jelmer.uk>\n"
-                "Alex <alexa@example.com>"}
+            "authors": "Jelmer Vernooij <jelmer@jelmer.uk>\nAlex <alexa@example.com>"
+        }
         r.committer = "Jelmer Vernooij <jelmer@apache.org>"
         r.timestamp = 453543543
         r.timezone = 0
         c = self.assertRoundtripRevision(r)
-        self.assertEqual(c.author, b'Jelmer Vernooij <jelmer@jelmer.uk>')
+        self.assertEqual(c.author, b"Jelmer Vernooij <jelmer@jelmer.uk>")
 
     def test_multiple_authors_comma(self):
         r = Revision(b"myrevid")
         r.message = "MyCommitMessage"
         r.parent_ids = []
         r.properties = {
-            "authors":
-                "Jelmer Vernooij <jelmer@jelmer.uk>, "
-                "Alex <alexa@example.com>"}
+            "authors": "Jelmer Vernooij <jelmer@jelmer.uk>, Alex <alexa@example.com>"
+        }
         r.committer = "Jelmer Vernooij <jelmer@apache.org>"
         r.timestamp = 453543543
         r.timezone = 0
         c = self.assertRoundtripRevision(r)
-        self.assertEqual(c.author, b'Jelmer Vernooij <jelmer@jelmer.uk>')
+        self.assertEqual(c.author, b"Jelmer Vernooij <jelmer@jelmer.uk>")
 
 
 class RoundtripRevisionsFromGit(tests.TestCase):
-
     def setUp(self):
         super().setUp()
         self.mapping = BzrGitMappingv1()
@@ -403,9 +431,9 @@ class RoundtripRevisionsFromGit(tests.TestCase):
 
     def assertRoundtripCommit(self, commit1):
         rev, roundtrip_revid, verifiers = self.mapping.import_commit(
-            commit1, self.mapping.revision_id_foreign_to_bzr, strict=True)
-        commit2 = self.mapping.export_commit(rev, "12341212121212", None,
-                                             True, None)
+            commit1, self.mapping.revision_id_foreign_to_bzr, strict=True
+        )
+        commit2 = self.mapping.export_commit(rev, "12341212121212", None, True, None)
         self.assertEqual(commit1.committer, commit2.committer)
         self.assertEqual(commit1.commit_time, commit2.commit_time)
         self.assertEqual(commit1.commit_timezone, commit2.commit_timezone)
@@ -457,7 +485,7 @@ class RoundtripRevisionsFromGit(tests.TestCase):
         c.tree = b"cc9462f7f8263ef5adfbeff2fb936bb36b504cba"
         c.message = b"Some message"
         c.committer = b"Committer <Committer>"
-        c.encoding = b'iso8859-1'
+        c.encoding = b"iso8859-1"
         c.commit_time = 4
         c.commit_timezone = -60 * 3
         c.author_time = 5
@@ -488,33 +516,38 @@ class RoundtripRevisionsFromGit(tests.TestCase):
         c.author_time = 5
         c.author_timezone = 60 * 2
         c.author = b"Author <author>"
-        tag = make_object(Tag,
-                          tagger=b'Jelmer Vernooij <jelmer@samba.org>',
-                          name=b'0.1', message=None,
-                          object=(
-                              Blob, b'd80c186a03f423a81b39df39dc87fd269736ca86'),
-                          tag_time=423423423, tag_timezone=0)
+        tag = make_object(
+            Tag,
+            tagger=b"Jelmer Vernooij <jelmer@samba.org>",
+            name=b"0.1",
+            message=None,
+            object=(Blob, b"d80c186a03f423a81b39df39dc87fd269736ca86"),
+            tag_time=423423423,
+            tag_timezone=0,
+        )
         c.mergetag = [tag]
         self.assertRoundtripCommit(c)
 
 
 class FixPersonIdentifierTests(tests.TestCase):
-
     def test_valid(self):
-        self.assertEqual(b"foo <bar@blah.nl>",
-                         fix_person_identifier(b"foo <bar@blah.nl>"))
-        self.assertEqual(b"bar@blah.nl <bar@blah.nl>",
-                         fix_person_identifier(b"bar@blah.nl"))
+        self.assertEqual(
+            b"foo <bar@blah.nl>", fix_person_identifier(b"foo <bar@blah.nl>")
+        )
+        self.assertEqual(
+            b"bar@blah.nl <bar@blah.nl>", fix_person_identifier(b"bar@blah.nl")
+        )
 
     def test_fix(self):
         self.assertEqual(
             b"person <bar@blah.nl>",
-            fix_person_identifier(b"somebody <person <bar@blah.nl>>"))
+            fix_person_identifier(b"somebody <person <bar@blah.nl>>"),
+        )
         self.assertEqual(
-            b"person <bar@blah.nl>",
-            fix_person_identifier(b"person<bar@blah.nl>"))
+            b"person <bar@blah.nl>", fix_person_identifier(b"person<bar@blah.nl>")
+        )
         self.assertEqual(
-            b'Rohan Garg <rohangarg@kubuntu.org>',
-            fix_person_identifier(b'Rohan Garg <rohangarg@kubuntu.org'))
-        self.assertRaises(ValueError,
-                          fix_person_identifier, b"person >bar@blah.nl<")
+            b"Rohan Garg <rohangarg@kubuntu.org>",
+            fix_person_identifier(b"Rohan Garg <rohangarg@kubuntu.org"),
+        )
+        self.assertRaises(ValueError, fix_person_identifier, b"person >bar@blah.nl<")
