@@ -14,8 +14,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-"""MemoryBranch object.
-"""
+"""MemoryBranch object."""
 
 from . import config as _mod_config
 from . import errors, osutils
@@ -26,7 +25,6 @@ from .tag import DisabledTags, MemoryTags
 
 
 class MemoryBranch(Branch, _RelockDebugMixin):
-
     def __init__(self, repository, last_revision_info, tags=None):
         self.repository = repository
         self._last_revision_info = last_revision_info
@@ -39,7 +37,7 @@ class MemoryBranch(Branch, _RelockDebugMixin):
         self._last_revision_info_cache = None
         self._revision_id_to_revno_cache = None
         self._partial_revision_id_to_revno_cache = {}
-        self.base = 'memory://' + osutils.rand_chars(10)
+        self.base = "memory://" + osutils.rand_chars(10)
 
     def __repr__(self):
         return "<MemoryBranch()>"
@@ -65,8 +63,7 @@ class MemoryBranch(Branch, _RelockDebugMixin):
         return self._last_revision_info
 
     def _gen_revision_history(self):
-        """Generate the revision history from last revision
-        """
+        """Generate the revision history from last revision."""
         with self.lock_read():
             self._extend_partial_history()
             return list(reversed(self._partial_revision_history_cache))
@@ -82,13 +79,13 @@ class MemoryBranch(Branch, _RelockDebugMixin):
             if last_revno is None:
                 self._extend_partial_history()
                 return self._partial_revision_history_cache[
-                    len(self._partial_revision_history_cache) - revno]
+                    len(self._partial_revision_history_cache) - revno
+                ]
             else:
                 if revno <= 0 or revno > last_revno:
                     raise errors.NoSuchRevision(self, revno)
                 distance_from_last = last_revno - revno
-                if len(self._partial_revision_history_cache) <= \
-                        distance_from_last:
+                if len(self._partial_revision_history_cache) <= distance_from_last:
                     self._extend_partial_history(distance_from_last)
                 return self._partial_revision_history_cache[distance_from_last]
 
@@ -101,4 +98,6 @@ class MemoryBranch(Branch, _RelockDebugMixin):
         :return: A breezy.config.BranchStack.
         """
         gstore = _mod_config.GlobalStore()
-        return _mod_config.Stack([_mod_config.NameMatcher(gstore, 'DEFAULT').get_sections])
+        return _mod_config.Stack(
+            [_mod_config.NameMatcher(gstore, "DEFAULT").get_sections]
+        )
