@@ -19,9 +19,12 @@
 
 def load_tests(loader, basic_tests, pattern):
     testmod_names = [
-        'test_committemplate',
-        'test_msgeditor',
-        ]
-    basic_tests.addTest(loader.loadTestsFromModuleNames(
-        ["{}.{}".format(__name__, tmn) for tmn in testmod_names]))
+        "test_committemplate",
+        "test_msgeditor",
+    ]
+    basic_tests.addTest(
+        loader.loadTestsFromModuleNames(
+            ["{}.{}".format(__name__, tmn) for tmn in testmod_names]
+        )
+    )
     return basic_tests
