@@ -15,6 +15,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """Map Tree."""
 
+
 def map_file_ids(repository, old_parents, new_parents):
     """Try to determine the equivalent file ids in two sets of parents.
 
@@ -24,7 +25,7 @@ def map_file_ids(repository, old_parents, new_parents):
     """
     assert len(old_parents) == len(new_parents)
     ret = {}
-    for (oldp, newp) in zip(old_parents, new_parents):
+    for oldp, newp in zip(old_parents, new_parents):
         oldtree = repository.revision_tree(oldp)
         newtree = repository.revision_tree(newp)
         for path, ie in oldtree.iter_entries_by_dir():
@@ -35,8 +36,7 @@ def map_file_ids(repository, old_parents, new_parents):
 
 
 class MapTree:
-    """Wrapper around a tree that translates file ids.
-    """
+    """Wrapper around a tree that translates file ids."""
 
     def __init__(self, oldtree, fileid_map):
         """Create a new MapTree.
@@ -70,30 +70,30 @@ class MapTree:
             return file_id
 
     def get_file_sha1(self, path, file_id=None):
-        "See Tree.get_file_sha1()."""
+        """See Tree.get_file_sha1()."""
         return self.oldtree.get_file_sha1(path)
 
     def get_file_with_stat(self, path, file_id=None):
-        "See Tree.get_file_with_stat()."""
+        """See Tree.get_file_with_stat()."""
         if getattr(self.oldtree, "get_file_with_stat", None) is not None:
             return self.oldtree.get_file_with_stat(path=path)
         else:
             return self.get_file(path), None
 
     def get_file(self, path, file_id=None):
-        "See Tree.get_file()."""
+        """See Tree.get_file()."""
         return self.oldtree.get_file(path)
 
     def is_executable(self, path, file_id=None):
-        "See Tree.is_executable()."""
+        """See Tree.is_executable()."""
         return self.oldtree.is_executable(path)
 
     def has_filename(self, filename):
-        "See Tree.has_filename()."""
+        """See Tree.has_filename()."""
         return self.oldtree.has_filename(filename)
 
     def path_content_summary(self, path):
-        "See Tree.path_content_summary()."""
+        """See Tree.path_content_summary()."""
         return self.oldtree.path_content_summary(path)
 
     def map_ie(self, ie):
@@ -118,5 +118,5 @@ class MapTree:
             return None
         return self.new_id(file_id)
 
-    def id2path(self, file_id, recurse='down'):
+    def id2path(self, file_id, recurse="down"):
         return self.oldtree.id2path(self.old_id(file_id=file_id), recurse=recurse)
