@@ -46,14 +46,14 @@ class ShelfReporter:
     vocab = {
         "add file": gettext('Shelve adding file "%(path)s"?'),
         "binary": gettext("Shelve binary changes?"),
-        "change kind": gettext('Shelve changing "%s" from %(other)s' " to %(this)s?"),
+        "change kind": gettext('Shelve changing "%s" from %(other)s to %(this)s?'),
         "delete file": gettext('Shelve removing file "%(path)s"?'),
         "final": gettext("Shelve %d change(s)?"),
         "hunk": gettext("Shelve?"),
         "modify target": gettext(
-            "Shelve changing target of" ' "%(path)s" from "%(other)s" to "%(this)s"?'
+            'Shelve changing target of "%(path)s" from "%(other)s" to "%(this)s"?'
         ),
-        "rename": gettext('Shelve renaming "%(other)s" =>' ' "%(this)s"?'),
+        "rename": gettext('Shelve renaming "%(other)s" => "%(this)s"?'),
     }
 
     invert_diff = False
@@ -97,12 +97,12 @@ class ApplyReporter(ShelfReporter):
     vocab = {
         "add file": gettext('Delete file "%(path)s"?'),
         "binary": gettext("Apply binary changes?"),
-        "change kind": gettext('Change "%(path)s" from %(this)s' " to %(other)s?"),
+        "change kind": gettext('Change "%(path)s" from %(this)s to %(other)s?'),
         "delete file": gettext('Add file "%(path)s"?'),
         "final": gettext("Apply %d change(s)?"),
         "hunk": gettext("Apply change?"),
         "modify target": gettext(
-            "Change target of" ' "%(path)s" from "%(this)s" to "%(other)s"?'
+            'Change target of "%(path)s" from "%(this)s" to "%(other)s"?'
         ),
         "rename": gettext('Rename "%(this)s" => "%(other)s"?'),
     }
@@ -264,7 +264,7 @@ class Shelver:
         text_differ = diff.DiffText(
             old_tree, new_tree, diff_file, path_encoding=path_encoding
         )
-        patch = text_differ.diff(old_path, new_path, "file", "file")
+        text_differ.diff(old_path, new_path, "file", "file")
         diff_file.seek(0)
         return patches.parse_patch(diff_file)
 
@@ -369,8 +369,7 @@ class Shelver:
         return lines, change_count
 
     def _edit_file(self, file_id, work_tree_lines):
-        """
-        :param file_id: id of the file to edit.
+        """:param file_id: id of the file to edit.
         :param work_tree_lines: Line contents of the file in the working tree.
         :return: (lines, change_region_count), where lines is the new line
             content of the file, and change_region_count is the number of
