@@ -14,24 +14,27 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-"""Tests for Branch.get_revision_id_to_revno_map()"""
+"""Tests for Branch.get_revision_id_to_revno_map()."""
 
 from breezy.tests.per_branch import TestCaseWithBranch
 
 
 class TestRevisionIdToDottedRevno(TestCaseWithBranch):
-
     def test_simple_revno(self):
         tree, revmap = self.create_tree_with_merge()
         # Re-open the branch so we make sure we start fresh.
         # see bug #162486
         the_branch = tree.controldir.open_branch()
 
-        self.assertEqual({revmap['1']: (1, ),
-                          revmap['2']: (2, ),
-                          revmap['3']: (3, ),
-                          revmap['1.1.1']: (1, 1, 1)
-                          }, the_branch.get_revision_id_to_revno_map())
+        self.assertEqual(
+            {
+                revmap["1"]: (1,),
+                revmap["2"]: (2,),
+                revmap["3"]: (3,),
+                revmap["1.1.1"]: (1, 1, 1),
+            },
+            the_branch.get_revision_id_to_revno_map(),
+        )
 
 
 class TestCaching(TestCaseWithBranch):
@@ -57,8 +60,9 @@ class TestCaching(TestCaseWithBranch):
         real_func = tree.branch._gen_revno_map
 
         def wrapper():
-            calls.append('_gen_revno_map')
+            calls.append("_gen_revno_map")
             return real_func()
+
         tree.branch._gen_revno_map = wrapper
         return tree.branch, revmap, calls
 
@@ -69,30 +73,36 @@ class TestCaching(TestCaseWithBranch):
         branch.get_revision_id_to_revno_map()
         branch.get_revision_id_to_revno_map()
         branch.get_revision_id_to_revno_map()
-        self.assertEqual(['_gen_revno_map'] * 3, calls)
+        self.assertEqual(["_gen_revno_map"] * 3, calls)
 
     def test_locked(self):
-        """Repeated calls will only call _gen_revno_map once.
-        """
+        """Repeated calls will only call _gen_revno_map once."""
         branch, revmap, calls = self.get_instrumented_branch()
         # Lock the branch, then repeatedly call revision_history.
         with branch.lock_read():
             branch.get_revision_id_to_revno_map()
-            self.assertEqual(['_gen_revno_map'], calls)
+            self.assertEqual(["_gen_revno_map"], calls)
 
     def test_set_last_revision_info_when_locked(self):
         """Calling set_last_revision_info should reset the cache."""
         branch, revmap, calls = self.get_instrumented_branch()
         with branch.lock_write():
-            self.assertEqual({revmap['1']: (1,),
-                              revmap['2']: (2, ),
-                              revmap['3']: (3, ),
-                              revmap['1.1.1']: (1, 1, 1)
-                              }, branch.get_revision_id_to_revno_map())
-            branch.set_last_revision_info(2, revmap['2'])
-            self.assertEqual({revmap['1']: (1, ),
-                              revmap['2']: (2, )},
-                             branch.get_revision_id_to_revno_map())
-            self.assertEqual({revmap['1']: (1, ), revmap['2']: (2, )},
-                             branch.get_revision_id_to_revno_map())
-            self.assertEqual(['_gen_revno_map'] * 2, calls)
+            self.assertEqual(
+                {
+                    revmap["1"]: (1,),
+                    revmap["2"]: (2,),
+                    revmap["3"]: (3,),
+                    revmap["1.1.1"]: (1, 1, 1),
+                },
+                branch.get_revision_id_to_revno_map(),
+            )
+            branch.set_last_revision_info(2, revmap["2"])
+            self.assertEqual(
+                {revmap["1"]: (1,), revmap["2"]: (2,)},
+                branch.get_revision_id_to_revno_map(),
+            )
+            self.assertEqual(
+                {revmap["1"]: (1,), revmap["2"]: (2,)},
+                branch.get_revision_id_to_revno_map(),
+            )
+            self.assertEqual(["_gen_revno_map"] * 2, calls)
