@@ -16,41 +16,52 @@
 
 """Tests for the core Hooks logic."""
 
-from .. import branch, errors
+from .. import branch, errors, pyutils, tests
 from .. import hooks as _mod_hooks
-from .. import pyutils, tests
-from ..hooks import (HookPoint, Hooks, UnknownHook, install_lazy_named_hook,
-                     known_hooks, known_hooks_key_to_object)
+from ..hooks import (
+    HookPoint,
+    Hooks,
+    UnknownHook,
+    install_lazy_named_hook,
+    known_hooks,
+    known_hooks_key_to_object,
+)
 
 
 class TestErrors(tests.TestCase):
-
     def test_unknown_hook(self):
         error = UnknownHook("branch", "foo")
-        self.assertEqualDiff("The branch hook 'foo' is unknown in this version"
-                             " of breezy.",
-                             str(error))
+        self.assertEqualDiff(
+            "The branch hook 'foo' is unknown in this version of breezy.", str(error)
+        )
         error = UnknownHook("tree", "bar")
-        self.assertEqualDiff("The tree hook 'bar' is unknown in this version"
-                             " of breezy.",
-                             str(error))
+        self.assertEqualDiff(
+            "The tree hook 'bar' is unknown in this version of breezy.", str(error)
+        )
 
 
 class TestHooks(tests.TestCase):
-
     def test_docs(self):
         """docs() should return something reasonable about the Hooks."""
+
         class MyHooks(Hooks):
             pass
+
         hooks = MyHooks("breezy.tests.test_hooks", "some_hooks")
-        hooks.add_hook('post_tip_change',
-                       "Invoked after the tip of a branch changes. Called with "
-                       "a ChangeBranchTipParams object.", (1, 4))
-        hooks.add_hook('pre_tip_change',
-                       "Invoked before the tip of a branch changes. Called with "
-                       "a ChangeBranchTipParams object. Hooks should raise "
-                       "TipChangeRejected to signal that a tip change is not permitted.",
-                       (1, 6), None)
+        hooks.add_hook(
+            "post_tip_change",
+            "Invoked after the tip of a branch changes. Called with "
+            "a ChangeBranchTipParams object.",
+            (1, 4),
+        )
+        hooks.add_hook(
+            "pre_tip_change",
+            "Invoked before the tip of a branch changes. Called with "
+            "a ChangeBranchTipParams object. Hooks should raise "
+            "TipChangeRejected to signal that a tip change is not permitted.",
+            (1, 6),
+            None,
+        )
         self.assertEqualDiff(
             "MyHooks\n"
             "-------\n"
@@ -70,29 +81,30 @@ class TestHooks(tests.TestCase):
             "\n"
             "Invoked before the tip of a branch changes. Called with a\n"
             "ChangeBranchTipParams object. Hooks should raise TipChangeRejected to\n"
-            "signal that a tip change is not permitted.\n", hooks.docs())
+            "signal that a tip change is not permitted.\n",
+            hooks.docs(),
+        )
 
     def test_install_named_hook_raises_unknown_hook(self):
         hooks = Hooks("breezy.tests.test_hooks", "some_hooks")
-        self.assertRaises(UnknownHook, hooks.install_named_hook, 'silly',
-                          None, "")
+        self.assertRaises(UnknownHook, hooks.install_named_hook, "silly", None, "")
 
     def test_install_named_hook_appends_known_hook(self):
         hooks = Hooks("breezy.tests.test_hooks", "some_hooks")
-        hooks['set_rh'] = []
-        hooks.install_named_hook('set_rh', None, "demo")
-        self.assertEqual(hooks['set_rh'], [None])
+        hooks["set_rh"] = []
+        hooks.install_named_hook("set_rh", None, "demo")
+        self.assertEqual(hooks["set_rh"], [None])
 
     def test_install_named_hook_and_retrieve_name(self):
         hooks = Hooks("breezy.tests.test_hooks", "somehooks")
-        hooks['set_rh'] = []
-        hooks.install_named_hook('set_rh', None, "demo")
+        hooks["set_rh"] = []
+        hooks.install_named_hook("set_rh", None, "demo")
         self.assertEqual("demo", hooks.get_hook_name(None))
 
     def test_uninstall_named_hook(self):
         hooks = Hooks("breezy.tests.test_hooks", "some_hooks")
-        hooks.add_hook('set_rh', "Set revision history", (2, 0))
-        hooks.install_named_hook('set_rh', None, "demo")
+        hooks.add_hook("set_rh", "Set revision history", (2, 0))
+        hooks.install_named_hook("set_rh", None, "demo")
         self.assertEqual(1, len(hooks["set_rh"]))
         hooks.uninstall_named_hook("set_rh", "demo")
         self.assertEqual(0, len(hooks["set_rh"]))
@@ -100,47 +112,51 @@ class TestHooks(tests.TestCase):
     def test_uninstall_multiple_named_hooks(self):
         # Multiple callbacks with the same label all get removed
         hooks = Hooks("breezy.tests.test_hooks", "some_hooks")
-        hooks.add_hook('set_rh', "Set revision history", (2, 0))
-        hooks.install_named_hook('set_rh', 1, "demo")
-        hooks.install_named_hook('set_rh', 2, "demo")
-        hooks.install_named_hook('set_rh', 3, "othername")
+        hooks.add_hook("set_rh", "Set revision history", (2, 0))
+        hooks.install_named_hook("set_rh", 1, "demo")
+        hooks.install_named_hook("set_rh", 2, "demo")
+        hooks.install_named_hook("set_rh", 3, "othername")
         self.assertEqual(3, len(hooks["set_rh"]))
         hooks.uninstall_named_hook("set_rh", "demo")
         self.assertEqual(1, len(hooks["set_rh"]))
 
     def test_uninstall_named_hook_unknown_callable(self):
         hooks = Hooks("breezy.tests.test_hooks", "some_hooks")
-        hooks.add_hook('set_rh', "Set revision hsitory", (2, 0))
-        self.assertRaises(KeyError, hooks.uninstall_named_hook, "set_rh",
-                          "demo")
+        hooks.add_hook("set_rh", "Set revision hsitory", (2, 0))
+        self.assertRaises(KeyError, hooks.uninstall_named_hook, "set_rh", "demo")
 
     def test_uninstall_named_hook_raises_unknown_hook(self):
         hooks = Hooks("breezy.tests.test_hooks", "some_hooks")
-        self.assertRaises(UnknownHook, hooks.uninstall_named_hook, 'silly', "")
+        self.assertRaises(UnknownHook, hooks.uninstall_named_hook, "silly", "")
 
     def test_uninstall_named_hook_old_style(self):
         hooks = Hooks("breezy.tests.test_hooks", "some_hooks")
         hooks["set_rh"] = []
-        hooks.install_named_hook('set_rh', None, "demo")
-        self.assertRaises(errors.UnsupportedOperation,
-                          hooks.uninstall_named_hook, "set_rh", "demo")
+        hooks.install_named_hook("set_rh", None, "demo")
+        self.assertRaises(
+            errors.UnsupportedOperation, hooks.uninstall_named_hook, "set_rh", "demo"
+        )
 
     hooks = Hooks("breezy.tests.test_hooks", "TestHooks.hooks")
 
     def test_install_lazy_named_hook(self):
         # When the hook points are not yet registered the hook is
         # added to the _lazy_hooks dictionary in breezy.hooks.
-        self.hooks.add_hook('set_rh', "doc", (0, 15))
+        self.hooks.add_hook("set_rh", "doc", (0, 15))
 
-        def set_rh(): return None
-        install_lazy_named_hook('breezy.tests.test_hooks',
-                                'TestHooks.hooks', 'set_rh', set_rh, "demo")
+        def set_rh():
+            return None
+
+        install_lazy_named_hook(
+            "breezy.tests.test_hooks", "TestHooks.hooks", "set_rh", set_rh, "demo"
+        )
         set_rh_lazy_hooks = _mod_hooks._lazy_hooks[
-            ('breezy.tests.test_hooks', 'TestHooks.hooks', 'set_rh')]
+            ("breezy.tests.test_hooks", "TestHooks.hooks", "set_rh")
+        ]
         self.assertEqual(1, len(set_rh_lazy_hooks))
         self.assertEqual(set_rh, set_rh_lazy_hooks[0][0].get_obj())
         self.assertEqual("demo", set_rh_lazy_hooks[0][1])
-        self.assertEqual(list(TestHooks.hooks['set_rh']), [set_rh])
+        self.assertEqual(list(TestHooks.hooks["set_rh"]), [set_rh])
 
     @classmethod
     def set_rh(cls):
@@ -148,20 +164,25 @@ class TestHooks(tests.TestCase):
 
     def test_install_named_hook_lazy(self):
         hooks = Hooks("breezy.tests.hooks", "some_hooks")
-        hooks['set_rh'] = HookPoint("set_rh", "doc", (0, 15), None)
-        hooks.install_named_hook_lazy('set_rh', 'breezy.tests.test_hooks',
-                                      'TestHooks.set_rh', "demo")
-        self.assertEqual(list(hooks['set_rh']), [TestHooks.set_rh])
+        hooks["set_rh"] = HookPoint("set_rh", "doc", (0, 15), None)
+        hooks.install_named_hook_lazy(
+            "set_rh", "breezy.tests.test_hooks", "TestHooks.set_rh", "demo"
+        )
+        self.assertEqual(list(hooks["set_rh"]), [TestHooks.set_rh])
 
     def test_install_named_hook_lazy_old(self):
         # An exception is raised if a lazy hook is raised for
         # an old style hook point.
         hooks = Hooks("breezy.tests.hooks", "some_hooks")
-        hooks['set_rh'] = []
-        self.assertRaises(errors.UnsupportedOperation,
-                          hooks.install_named_hook_lazy,
-                          'set_rh', 'breezy.tests.test_hooks', 'TestHooks.set_rh',
-                          "demo")
+        hooks["set_rh"] = []
+        self.assertRaises(
+            errors.UnsupportedOperation,
+            hooks.install_named_hook_lazy,
+            "set_rh",
+            "breezy.tests.test_hooks",
+            "TestHooks.set_rh",
+            "demo",
+        )
 
     def test_valid_lazy_hooks(self):
         # Make sure that all the registered lazy hooks are referring to existing
@@ -176,10 +197,11 @@ class TestHooks(tests.TestCase):
 
 
 class TestHook(tests.TestCase):
-
     def test___init__(self):
-        doc = ("Invoked after changing the tip of a branch object. Called with"
-               "a breezy.branch.PostChangeBranchTipParams object")
+        doc = (
+            "Invoked after changing the tip of a branch object. Called with"
+            "a breezy.branch.PostChangeBranchTipParams object"
+        )
         hook = HookPoint("post_tip_change", doc, (0, 15), None)
         self.assertEqual(doc, hook.__doc__)
         self.assertEqual("post_tip_change", hook.name)
@@ -188,22 +210,28 @@ class TestHook(tests.TestCase):
         self.assertEqual([], list(hook))
 
     def test_docs(self):
-        doc = ("Invoked after changing the tip of a branch object. Called with"
-               " a breezy.branch.PostChangeBranchTipParams object")
+        doc = (
+            "Invoked after changing the tip of a branch object. Called with"
+            " a breezy.branch.PostChangeBranchTipParams object"
+        )
         hook = HookPoint("post_tip_change", doc, (0, 15), None)
-        self.assertEqual("post_tip_change\n"
-                         "~~~~~~~~~~~~~~~\n"
-                         "\n"
-                         "Introduced in: 0.15\n"
-                         "\n"
-                         "Invoked after changing the tip of a branch object. Called with a\n"
-                         "breezy.branch.PostChangeBranchTipParams object\n", hook.docs())
+        self.assertEqual(
+            "post_tip_change\n"
+            "~~~~~~~~~~~~~~~\n"
+            "\n"
+            "Introduced in: 0.15\n"
+            "\n"
+            "Invoked after changing the tip of a branch object. Called with a\n"
+            "breezy.branch.PostChangeBranchTipParams object\n",
+            hook.docs(),
+        )
 
     def test_hook(self):
         hook = HookPoint("foo", "no docs", None, None)
 
         def callback():
             pass
+
         hook.hook(callback, "my callback")
         self.assertEqual([callback], list(hook))
 
@@ -214,15 +242,15 @@ class TestHook(tests.TestCase):
     def test_lazy_hook(self):
         hook = HookPoint("foo", "no docs", None, None)
         hook.hook_lazy(
-            "breezy.tests.test_hooks", "TestHook.lazy_callback",
-            "my callback")
+            "breezy.tests.test_hooks", "TestHook.lazy_callback", "my callback"
+        )
         self.assertEqual([TestHook.lazy_callback], list(hook))
 
     def test_uninstall(self):
         hook = HookPoint("foo", "no docs", None, None)
         hook.hook_lazy(
-            "breezy.tests.test_hooks", "TestHook.lazy_callback",
-            "my callback")
+            "breezy.tests.test_hooks", "TestHook.lazy_callback", "my callback"
+        )
         self.assertEqual([TestHook.lazy_callback], list(hook))
         hook.uninstall("my callback")
         self.assertEqual([], list(hook))
@@ -237,15 +265,16 @@ class TestHook(tests.TestCase):
 
         def callback():
             pass
+
         hook.hook(callback, "my callback")
         callback_repr = repr(callback)
         self.assertEqual(
-            '<HookPoint(foo), callbacks=[%s(my callback)]>' %
-            callback_repr, repr(hook))
+            "<HookPoint(foo), callbacks=[{}(my callback)]>".format(callback_repr),
+            repr(hook),
+        )
 
 
 class TestHookRegistry(tests.TestCase):
-
     def test_items_are_reasonable_keys(self):
         # All the items in the known_hooks registry need to map from
         # (module_name, member_name) tuples to the callable used to get an
@@ -253,8 +282,10 @@ class TestHookRegistry(tests.TestCase):
         # suite which needs to generate empty hooks (and HookPoints) to ensure
         # isolation and prevent tests failing spuriously.
         for key, factory in known_hooks.items():
-            self.assertTrue(callable(factory),
-                            "The factory({!r}) for {!r} is not callable".format(factory, key))
+            self.assertTrue(
+                callable(factory),
+                "The factory({!r}) for {!r} is not callable".format(factory, key),
+            )
             obj = known_hooks_key_to_object(key)
             self.assertIsInstance(obj, Hooks)
             new_hooks = factory()
@@ -263,13 +294,17 @@ class TestHookRegistry(tests.TestCase):
             self.assertEqual("No hook name", new_hooks.get_hook_name(None))
 
     def test_known_hooks_key_to_object(self):
-        self.assertIs(branch.Branch.hooks,
-                      known_hooks_key_to_object(('breezy.branch', 'Branch.hooks')))
+        self.assertIs(
+            branch.Branch.hooks,
+            known_hooks_key_to_object(("breezy.branch", "Branch.hooks")),
+        )
 
     def test_known_hooks_key_to_parent_and_attribute(self):
-        self.assertEqual((branch.Branch, 'hooks'),
-                         known_hooks.key_to_parent_and_attribute(
-            ('breezy.branch', 'Branch.hooks')))
-        self.assertEqual((branch, 'Branch'),
-                         known_hooks.key_to_parent_and_attribute(
-            ('breezy.branch', 'Branch')))
+        self.assertEqual(
+            (branch.Branch, "hooks"),
+            known_hooks.key_to_parent_and_attribute(("breezy.branch", "Branch.hooks")),
+        )
+        self.assertEqual(
+            (branch, "Branch"),
+            known_hooks.key_to_parent_and_attribute(("breezy.branch", "Branch")),
+        )
