@@ -14,7 +14,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-"""Tests for LockDir"""
+"""Tests for LockDir."""
 
 import os
 import time
@@ -22,10 +22,15 @@ import time
 import breezy
 
 from .. import config, errors, lock, lockdir, osutils, tests, transport
-from ..errors import (LockBreakMismatch, LockBroken, LockContention,
-                      LockFailed, LockNotHeld)
+from ..errors import (
+    LockBreakMismatch,
+    LockBroken,
+    LockContention,
+    LockFailed,
+    LockNotHeld,
+)
 from ..lockdir import LockDir, LockHeldInfo
-from . import TestCase, TestCaseInTempDir, TestCaseWithTransport, features
+from . import TestCaseInTempDir, TestCaseWithTransport, features
 
 # These tests are run on the default transport provided by the test framework
 # (typically a local disk transport).  That can be changed by the --transport
@@ -35,7 +40,7 @@ from . import TestCase, TestCaseInTempDir, TestCaseWithTransport, features
 
 
 class TestLockDir(TestCaseWithTransport):
-    """Test LockDir operations"""
+    """Test LockDir operations."""
 
     def logging_report_function(self, fmt, *args):
         self._logged_reports.append((fmt, args))
@@ -45,23 +50,23 @@ class TestLockDir(TestCaseWithTransport):
         lock_dir._report_function = self.logging_report_function
 
     def test_00_lock_creation(self):
-        """Creation of lock file on a transport"""
+        """Creation of lock file on a transport."""
         t = self.get_transport()
-        lf = LockDir(t, 'test_lock')
+        lf = LockDir(t, "test_lock")
         self.assertFalse(lf.is_held)
 
     def test_01_lock_repr(self):
-        """Lock string representation"""
-        lf = LockDir(self.get_transport(), 'test_lock')
+        """Lock string representation."""
+        lf = LockDir(self.get_transport(), "test_lock")
         r = repr(lf)
-        self.assertContainsRe(r, r'^LockDir\(.*/test_lock\)$')
+        self.assertContainsRe(r, r"^LockDir\(.*/test_lock\)$")
 
     def test_02_unlocked_peek(self):
-        lf = LockDir(self.get_transport(), 'test_lock')
+        lf = LockDir(self.get_transport(), "test_lock")
         self.assertEqual(lf.peek(), None)
 
     def get_lock(self):
-        return LockDir(self.get_transport(), 'test_lock')
+        return LockDir(self.get_transport(), "test_lock")
 
     def test_unlock_after_break_raises(self):
         ld = self.get_lock()
@@ -72,13 +77,13 @@ class TestLockDir(TestCaseWithTransport):
         self.assertRaises(LockBroken, ld.unlock)
 
     def test_03_readonly_peek(self):
-        lf = LockDir(self.get_readonly_transport(), 'test_lock')
+        lf = LockDir(self.get_readonly_transport(), "test_lock")
         self.assertEqual(lf.peek(), None)
 
     def test_10_lock_uncontested(self):
-        """Acquire and release a lock"""
+        """Acquire and release a lock."""
         t = self.get_transport()
-        lf = LockDir(t, 'test_lock')
+        lf = LockDir(t, "test_lock")
         lf.create()
         lf.attempt_lock()
         try:
@@ -88,60 +93,61 @@ class TestLockDir(TestCaseWithTransport):
             self.assertFalse(lf.is_held)
 
     def test_11_create_readonly_transport(self):
-        """Fail to create lock on readonly transport"""
+        """Fail to create lock on readonly transport."""
         t = self.get_readonly_transport()
-        lf = LockDir(t, 'test_lock')
+        lf = LockDir(t, "test_lock")
         self.assertRaises(LockFailed, lf.create)
 
     def test_12_lock_readonly_transport(self):
-        """Fail to lock on readonly transport"""
-        lf = LockDir(self.get_transport(), 'test_lock')
+        """Fail to lock on readonly transport."""
+        lf = LockDir(self.get_transport(), "test_lock")
         lf.create()
-        lf = LockDir(self.get_readonly_transport(), 'test_lock')
+        lf = LockDir(self.get_readonly_transport(), "test_lock")
         self.assertRaises(LockFailed, lf.attempt_lock)
 
     def test_20_lock_contested(self):
-        """Contention to get a lock"""
+        """Contention to get a lock."""
         t = self.get_transport()
-        lf1 = LockDir(t, 'test_lock')
+        lf1 = LockDir(t, "test_lock")
         lf1.create()
         lf1.attempt_lock()
-        lf2 = LockDir(t, 'test_lock')
+        lf2 = LockDir(t, "test_lock")
         try:
             # locking is between LockDir instances; aliases within
             # a single process are not detected
             lf2.attempt_lock()
-            self.fail('Failed to detect lock collision')
+            self.fail("Failed to detect lock collision")
         except LockContention as e:
             self.assertEqual(e.lock, lf2)
-            self.assertContainsRe(str(e),
-                                  r'^Could not acquire.*test_lock.*$')
+            self.assertContainsRe(str(e), r"^Could not acquire.*test_lock.*$")
         lf1.unlock()
 
     def test_20_lock_peek(self):
-        """Peek at the state of a lock"""
+        """Peek at the state of a lock."""
         t = self.get_transport()
-        lf1 = LockDir(t, 'test_lock')
+        lf1 = LockDir(t, "test_lock")
         lf1.create()
         lf1.attempt_lock()
         self.addCleanup(lf1.unlock)
         # lock is held, should get some info on it
         info1 = lf1.peek()
-        self.assertEqual(set(info1.info_dict.keys()),
-                         {'user', 'nonce', 'hostname', 'pid', 'start_time'})
+        self.assertEqual(
+            set(info1.info_dict.keys()),
+            {"user", "nonce", "hostname", "pid", "start_time"},
+        )
         # should get the same info if we look at it through a different
         # instance
-        info2 = LockDir(t, 'test_lock').peek()
+        info2 = LockDir(t, "test_lock").peek()
         self.assertEqual(info1, info2)
         # locks which are never used should be not-held
-        self.assertEqual(LockDir(t, 'other_lock').peek(), None)
+        self.assertEqual(LockDir(t, "other_lock").peek(), None)
 
     def test_21_peek_readonly(self):
-        """Peek over a readonly transport"""
+        """Peek over a readonly transport."""
         t = self.get_transport()
-        lf1 = LockDir(t, 'test_lock')
+        lf1 = LockDir(t, "test_lock")
         lf1.create()
-        lf2 = LockDir(self.get_readonly_transport(), 'test_lock')
+        lf2 = LockDir(self.get_readonly_transport(), "test_lock")
         self.assertEqual(lf2.peek(), None)
         lf1.attempt_lock()
         self.addCleanup(lf1.unlock)
@@ -150,42 +156,44 @@ class TestLockDir(TestCaseWithTransport):
         self.assertEqual(info2.nonce, lf1.nonce)
 
     def test_30_lock_wait_fail(self):
-        """Wait on a lock, then fail
+        """Wait on a lock, then fail.
 
         We ask to wait up to 400ms; this should fail within at most one
         second.  (Longer times are more realistic but we don't want the test
         suite to take too long, and this should do for now.)
         """
         t = self.get_transport()
-        lf1 = LockDir(t, 'test_lock')
+        lf1 = LockDir(t, "test_lock")
         lf1.create()
-        lf2 = LockDir(t, 'test_lock')
+        lf2 = LockDir(t, "test_lock")
         self.setup_log_reporter(lf2)
         lf1.attempt_lock()
         try:
             before = time.time()
-            self.assertRaises(LockContention, lf2.wait_lock,
-                              timeout=0.4, poll=0.1)
+            self.assertRaises(LockContention, lf2.wait_lock, timeout=0.4, poll=0.1)
             after = time.time()
             # it should only take about 0.4 seconds, but we allow more time in
             # case the machine is heavily loaded
-            self.assertTrue(after - before <= 8.0,
-                            "took %f seconds to detect lock contention" % (after - before))
+            self.assertTrue(
+                after - before <= 8.0,
+                "took %f seconds to detect lock contention" % (after - before),
+            )
         finally:
             lf1.unlock()
         self.assertEqual(1, len(self._logged_reports))
-        self.assertContainsRe(self._logged_reports[0][0],
-                              r'Unable to obtain lock .* held by jrandom@example\.com on .*'
-                              r' \(process #\d+\), acquired .* ago\.\n'
-                              r'Will continue to try until \d{2}:\d{2}:\d{2}, unless '
-                              r'you press Ctrl-C.\n'
-                              r'See "brz help break-lock" for more.')
+        self.assertContainsRe(
+            self._logged_reports[0][0],
+            r"Unable to obtain lock .* held by jrandom@example\.com on .*"
+            r" \(process #\d+\), acquired .* ago\.\n"
+            r"Will continue to try until \d{2}:\d{2}:\d{2}, unless "
+            r"you press Ctrl-C.\n"
+            r'See "brz help break-lock" for more.',
+        )
 
     def test_31_lock_wait_easy(self):
-        """Succeed when waiting on a lock with no contention.
-        """
+        """Succeed when waiting on a lock with no contention."""
         t = self.get_transport()
-        lf1 = LockDir(t, 'test_lock')
+        lf1 = LockDir(t, "test_lock")
         lf1.create()
         self.setup_log_reporter(lf1)
         try:
@@ -198,43 +206,43 @@ class TestLockDir(TestCaseWithTransport):
         self.assertEqual([], self._logged_reports)
 
     def test_40_confirm_easy(self):
-        """Confirm a lock that's already held"""
+        """Confirm a lock that's already held."""
         t = self.get_transport()
-        lf1 = LockDir(t, 'test_lock')
+        lf1 = LockDir(t, "test_lock")
         lf1.create()
         lf1.attempt_lock()
         self.addCleanup(lf1.unlock)
         lf1.confirm()
 
     def test_41_confirm_not_held(self):
-        """Confirm a lock that's already held"""
+        """Confirm a lock that's already held."""
         t = self.get_transport()
-        lf1 = LockDir(t, 'test_lock')
+        lf1 = LockDir(t, "test_lock")
         lf1.create()
         self.assertRaises(LockNotHeld, lf1.confirm)
 
     def test_42_confirm_broken_manually(self):
-        """Confirm a lock broken by hand"""
+        """Confirm a lock broken by hand."""
         t = self.get_transport()
-        lf1 = LockDir(t, 'test_lock')
+        lf1 = LockDir(t, "test_lock")
         lf1.create()
         lf1.attempt_lock()
-        t.move('test_lock', 'lock_gone_now')
+        t.move("test_lock", "lock_gone_now")
         self.assertRaises(LockBroken, lf1.confirm)
         # Clean up
-        t.move('lock_gone_now', 'test_lock')
+        t.move("lock_gone_now", "test_lock")
         lf1.unlock()
 
     def test_43_break(self):
-        """Break a lock whose caller has forgotten it"""
+        """Break a lock whose caller has forgotten it."""
         t = self.get_transport()
-        lf1 = LockDir(t, 'test_lock')
+        lf1 = LockDir(t, "test_lock")
         lf1.create()
         lf1.attempt_lock()
         # we incorrectly discard the lock object without unlocking it
         del lf1
         # someone else sees it's still locked
-        lf2 = LockDir(t, 'test_lock')
+        lf2 = LockDir(t, "test_lock")
         holder_info = lf2.peek()
         self.assertTrue(holder_info)
         lf2.force_break(holder_info)
@@ -244,13 +252,13 @@ class TestLockDir(TestCaseWithTransport):
         lf2.confirm()
 
     def test_44_break_already_released(self):
-        """Lock break races with regular release"""
+        """Lock break races with regular release."""
         t = self.get_transport()
-        lf1 = LockDir(t, 'test_lock')
+        lf1 = LockDir(t, "test_lock")
         lf1.create()
         lf1.attempt_lock()
         # someone else sees it's still locked
-        lf2 = LockDir(t, 'test_lock')
+        lf2 = LockDir(t, "test_lock")
         holder_info = lf2.peek()
         # in the interim the lock is released
         lf1.unlock()
@@ -262,26 +270,25 @@ class TestLockDir(TestCaseWithTransport):
         lf2.confirm()
 
     def test_45_break_mismatch(self):
-        """Lock break races with someone else acquiring it"""
+        """Lock break races with someone else acquiring it."""
         t = self.get_transport()
-        lf1 = LockDir(t, 'test_lock')
+        lf1 = LockDir(t, "test_lock")
         lf1.create()
         lf1.attempt_lock()
         # someone else sees it's still locked
-        lf2 = LockDir(t, 'test_lock')
+        lf2 = LockDir(t, "test_lock")
         holder_info = lf2.peek()
         # in the interim the lock is released
         lf1.unlock()
-        lf3 = LockDir(t, 'test_lock')
+        lf3 = LockDir(t, "test_lock")
         lf3.attempt_lock()
         # break should now *fail*
-        self.assertRaises(LockBreakMismatch, lf2.force_break,
-                          holder_info)
+        self.assertRaises(LockBreakMismatch, lf2.force_break, holder_info)
         lf3.unlock()
 
     def test_46_fake_read_lock(self):
         t = self.get_transport()
-        lf1 = LockDir(t, 'test_lock')
+        lf1 = LockDir(t, "test_lock")
         lf1.create()
         lf1.lock_read()
         lf1.unlock()
@@ -294,13 +301,13 @@ class TestLockDir(TestCaseWithTransport):
         containing an info file.
         """
         t = self.get_transport()
-        lf1 = LockDir(t, 'test_lock')
+        lf1 = LockDir(t, "test_lock")
         lf1.create()
-        self.assertTrue(t.has('test_lock'))
+        self.assertTrue(t.has("test_lock"))
         lf1.lock_write()
-        self.assertTrue(t.has('test_lock/held/info'))
+        self.assertTrue(t.has("test_lock/held/info"))
         lf1.unlock()
-        self.assertFalse(t.has('test_lock/held/info'))
+        self.assertFalse(t.has("test_lock/held/info"))
 
     def test_break_lock(self):
         # the ui based break_lock routine should Just Work (tm)
@@ -326,22 +333,22 @@ class TestLockDir(TestCaseWithTransport):
         ld2 = self.get_lock()
         ld.create()
         ld.lock_write()
-        ld.transport.put_bytes_non_atomic('test_lock/held/info', b'\0')
+        ld.transport.put_bytes_non_atomic("test_lock/held/info", b"\0")
 
         class LoggingUIFactory(breezy.ui.SilentUIFactory):
             def __init__(self):
                 self.prompts = []
 
             def get_boolean(self, prompt):
-                self.prompts.append(('boolean', prompt))
+                self.prompts.append(("boolean", prompt))
                 return True
 
         ui = LoggingUIFactory()
-        self.overrideAttr(breezy.ui, 'ui_factory', ui)
+        self.overrideAttr(breezy.ui, "ui_factory", ui)
         ld2.break_lock()
         self.assertLength(1, ui.prompts)
-        self.assertEqual('boolean', ui.prompts[0][0])
-        self.assertStartsWith(ui.prompts[0][1], 'Break (corrupt LockDir')
+        self.assertEqual("boolean", ui.prompts[0][0])
+        self.assertStartsWith(ui.prompts[0][1], "Break (corrupt LockDir")
         self.assertRaises(LockBroken, ld.unlock)
 
     def test_break_lock_missing_info(self):
@@ -352,14 +359,14 @@ class TestLockDir(TestCaseWithTransport):
         ld2 = self.get_lock()
         ld.create()
         ld.lock_write()
-        ld.transport.delete('test_lock/held/info')
+        ld.transport.delete("test_lock/held/info")
 
         class LoggingUIFactory(breezy.ui.SilentUIFactory):
             def __init__(self):
                 self.prompts = []
 
             def get_boolean(self, prompt):
-                self.prompts.append(('boolean', prompt))
+                self.prompts.append(("boolean", prompt))
                 return True
 
         ui = LoggingUIFactory()
@@ -377,28 +384,28 @@ class TestLockDir(TestCaseWithTransport):
         del self._lock_actions[:]
 
     def test_create_missing_base_directory(self):
-        """If LockDir.path doesn't exist, it can be created
+        """If LockDir.path doesn't exist, it can be created.
 
         Some people manually remove the entire lock/ directory trying
         to unlock a stuck repository/branch/etc. Rather than failing
         after that, just create the lock directory when needed.
         """
         t = self.get_transport()
-        lf1 = LockDir(t, 'test_lock')
+        lf1 = LockDir(t, "test_lock")
 
         lf1.create()
-        self.assertTrue(t.has('test_lock'))
+        self.assertTrue(t.has("test_lock"))
 
-        t.rmdir('test_lock')
-        self.assertFalse(t.has('test_lock'))
+        t.rmdir("test_lock")
+        self.assertFalse(t.has("test_lock"))
 
         # This will create 'test_lock' if it needs to
         lf1.lock_write()
-        self.assertTrue(t.has('test_lock'))
-        self.assertTrue(t.has('test_lock/held/info'))
+        self.assertTrue(t.has("test_lock"))
+        self.assertTrue(t.has("test_lock/held/info"))
 
         lf1.unlock()
-        self.assertFalse(t.has('test_lock/held/info'))
+        self.assertFalse(t.has("test_lock/held/info"))
 
     def test_display_form(self):
         ld1 = self.get_lock()
@@ -408,14 +415,14 @@ class TestLockDir(TestCaseWithTransport):
             info_list = ld1.peek().to_readable_dict()
         finally:
             ld1.unlock()
-        self.assertEqual(info_list['user'], 'jrandom@example.com')
-        self.assertIsInstance(info_list['pid'], int)
-        self.assertContainsRe(info_list['time_ago'], '^\\d+ seconds? ago$')
+        self.assertEqual(info_list["user"], "jrandom@example.com")
+        self.assertIsInstance(info_list["pid"], int)
+        self.assertContainsRe(info_list["time_ago"], "^\\d+ seconds? ago$")
 
     def test_lock_without_email(self):
         global_config = config.GlobalStack()
         # Intentionally has no email address
-        global_config.set('email', 'User Identity')
+        global_config.set("email", "User Identity")
         ld1 = self.get_lock()
         ld1.create()
         ld1.lock_write()
@@ -424,9 +431,9 @@ class TestLockDir(TestCaseWithTransport):
     def test_lock_permission(self):
         self.requireFeature(features.not_running_as_root)
         if not osutils.supports_posix_readonly():
-            raise tests.TestSkipped('Cannot induce a permission failure')
+            raise tests.TestSkipped("Cannot induce a permission failure")
         ld1 = self.get_lock()
-        lock_path = ld1.transport.local_abspath('test_lock')
+        lock_path = ld1.transport.local_abspath("test_lock")
         os.mkdir(lock_path)
         osutils.make_readonly(lock_path)
         self.assertRaises(errors.LockFailed, ld1.attempt_lock)
@@ -444,18 +451,17 @@ class TestLockDir(TestCaseWithTransport):
     def test_lock_with_buggy_rename(self):
         # test that lock acquisition handles servers which pretend they
         # renamed correctly but that actually fail
-        t = transport.get_transport_from_url(
-            'brokenrename+' + self.get_url())
-        ld1 = LockDir(t, 'test_lock')
+        t = transport.get_transport_from_url("brokenrename+" + self.get_url())
+        ld1 = LockDir(t, "test_lock")
         ld1.create()
         ld1.attempt_lock()
-        ld2 = LockDir(t, 'test_lock')
+        ld2 = LockDir(t, "test_lock")
         # we should fail to lock
-        e = self.assertRaises(errors.LockContention, ld2.attempt_lock)
+        self.assertRaises(errors.LockContention, ld2.attempt_lock)
         # now the original caller should succeed in unlocking
         ld1.unlock()
         # and there should be nothing left over
-        self.assertEqual([], t.list_dir('test_lock'))
+        self.assertEqual([], t.list_dir("test_lock"))
 
     def test_failed_lock_leaves_no_trash(self):
         # if we fail to acquire the lock, we don't leave pending directories
@@ -464,20 +470,20 @@ class TestLockDir(TestCaseWithTransport):
         ld2 = self.get_lock()
         # should be nothing before we start
         ld1.create()
-        t = self.get_transport().clone('test_lock')
+        t = self.get_transport().clone("test_lock")
 
         def check_dir(a):
-            self.assertEqual(a, t.list_dir('.'))
+            self.assertEqual(a, t.list_dir("."))
 
         check_dir([])
         # when held, that's all we see
         ld1.attempt_lock()
         self.addCleanup(ld1.unlock)
-        check_dir(['held'])
+        check_dir(["held"])
         # second guy should fail
         self.assertRaises(errors.LockContention, ld2.attempt_lock)
         # no kibble
-        check_dir(['held'])
+        check_dir(["held"])
 
     def test_no_lockdir_info(self):
         """We can cope with empty info files."""
@@ -486,16 +492,21 @@ class TestLockDir(TestCaseWithTransport):
         # Processes are often interrupted after opening the file
         # before the actual contents are committed.
         t = self.get_transport()
-        t.mkdir('test_lock')
-        t.mkdir('test_lock/held')
-        t.put_bytes('test_lock/held/info', b'')
-        lf = LockDir(t, 'test_lock')
+        t.mkdir("test_lock")
+        t.mkdir("test_lock/held")
+        t.put_bytes("test_lock/held/info", b"")
+        lf = LockDir(t, "test_lock")
         info = lf.peek()
         formatted_info = info.to_readable_dict()
         self.assertEqual(
-            dict(user='<unknown>', hostname='<unknown>', pid='<unknown>',
-                 time_ago='(unknown)'),
-            formatted_info)
+            {
+                "user": "<unknown>",
+                "hostname": "<unknown>",
+                "pid": "<unknown>",
+                "time_ago": "(unknown)",
+            },
+            formatted_info,
+        )
 
     def test_corrupt_lockdir_info(self):
         """We can cope with corrupt (and thus unparseable) info files."""
@@ -504,23 +515,22 @@ class TestLockDir(TestCaseWithTransport):
         # In particular some systems tend to fill recently created files with
         # nul bytes after recovering from a system crash.
         t = self.get_transport()
-        t.mkdir('test_lock')
-        t.mkdir('test_lock/held')
-        t.put_bytes('test_lock/held/info', b'\0')
-        lf = LockDir(t, 'test_lock')
+        t.mkdir("test_lock")
+        t.mkdir("test_lock/held")
+        t.put_bytes("test_lock/held/info", b"\0")
+        lf = LockDir(t, "test_lock")
         self.assertRaises(errors.LockCorrupt, lf.peek)
         # Currently attempt_lock gives LockContention, but LockCorrupt would be
         # a reasonable result too.
-        self.assertRaises(
-            (errors.LockCorrupt, errors.LockContention), lf.attempt_lock)
-        self.assertRaises(errors.LockCorrupt, lf.validate_token, 'fake token')
+        self.assertRaises((errors.LockCorrupt, errors.LockContention), lf.attempt_lock)
+        self.assertRaises(errors.LockCorrupt, lf.validate_token, "fake token")
 
     def test_missing_lockdir_info(self):
         """We can cope with absent info files."""
         t = self.get_transport()
-        t.mkdir('test_lock')
-        t.mkdir('test_lock/held')
-        lf = LockDir(t, 'test_lock')
+        t.mkdir("test_lock")
+        t.mkdir("test_lock/held")
+        lf = LockDir(t, "test_lock")
         # In this case we expect the 'not held' result from peek, because peek
         # cannot be expected to notice that there is a 'held' directory with no
         # 'info' file.
@@ -539,26 +549,26 @@ class TestLockDir(TestCaseWithTransport):
         # Currently raises TokenMismatch, but LockCorrupt would be reasonable
         # too.
         self.assertRaises(
-            (errors.TokenMismatch, errors.LockCorrupt),
-            lf.validate_token, 'fake token')
+            (errors.TokenMismatch, errors.LockCorrupt), lf.validate_token, "fake token"
+        )
 
 
 class TestLockDirHooks(TestCaseWithTransport):
-
     def setUp(self):
         super().setUp()
         self._calls = []
 
     def get_lock(self):
-        return LockDir(self.get_transport(), 'test_lock')
+        return LockDir(self.get_transport(), "test_lock")
 
     def record_hook(self, result):
         self._calls.append(result)
 
     def test_LockDir_acquired_success(self):
         # the LockDir.lock_acquired hook fires when a lock is acquired.
-        LockDir.hooks.install_named_hook('lock_acquired',
-                                         self.record_hook, 'record_hook')
+        LockDir.hooks.install_named_hook(
+            "lock_acquired", self.record_hook, "record_hook"
+        )
         ld = self.get_lock()
         ld.create()
         self.assertEqual([], self._calls)
@@ -575,8 +585,9 @@ class TestLockDirHooks(TestCaseWithTransport):
         ld2 = self.get_lock()
         ld2.attempt_lock()
         # install a lock hook now, when the disk lock is locked
-        LockDir.hooks.install_named_hook('lock_acquired',
-                                         self.record_hook, 'record_hook')
+        LockDir.hooks.install_named_hook(
+            "lock_acquired", self.record_hook, "record_hook"
+        )
         self.assertRaises(errors.LockContention, ld.attempt_lock)
         self.assertEqual([], self._calls)
         ld2.unlock()
@@ -584,8 +595,9 @@ class TestLockDirHooks(TestCaseWithTransport):
 
     def test_LockDir_released_success(self):
         # the LockDir.lock_released hook fires when a lock is acquired.
-        LockDir.hooks.install_named_hook('lock_released',
-                                         self.record_hook, 'record_hook')
+        LockDir.hooks.install_named_hook(
+            "lock_released", self.record_hook, "record_hook"
+        )
         ld = self.get_lock()
         ld.create()
         self.assertEqual([], self._calls)
@@ -602,8 +614,9 @@ class TestLockDirHooks(TestCaseWithTransport):
         ld2 = self.get_lock()
         ld.attempt_lock()
         ld2.force_break(ld2.peek())
-        LockDir.hooks.install_named_hook('lock_released',
-                                         self.record_hook, 'record_hook')
+        LockDir.hooks.install_named_hook(
+            "lock_released", self.record_hook, "record_hook"
+        )
         self.assertRaises(LockBroken, ld.unlock)
         self.assertEqual([], self._calls)
 
@@ -613,8 +626,7 @@ class TestLockDirHooks(TestCaseWithTransport):
         ld.create()
         ld2 = self.get_lock()
         result = ld.attempt_lock()
-        LockDir.hooks.install_named_hook('lock_broken',
-                                         self.record_hook, 'record_hook')
+        LockDir.hooks.install_named_hook("lock_broken", self.record_hook, "record_hook")
         ld2.force_break(ld2.peek())
         lock_path = ld.transport.abspath(ld.path)
         self.assertEqual([lock.LockResult(lock_path, result)], self._calls)
@@ -625,19 +637,19 @@ class TestLockDirHooks(TestCaseWithTransport):
         ld = self.get_lock()
         ld.create()
         ld2 = self.get_lock()
-        result = ld.attempt_lock()
+        ld.attempt_lock()
         holder_info = ld2.peek()
         ld.unlock()
-        LockDir.hooks.install_named_hook('lock_broken',
-                                         self.record_hook, 'record_hook')
+        LockDir.hooks.install_named_hook("lock_broken", self.record_hook, "record_hook")
         ld2.force_break(holder_info)
-        lock_path = ld.transport.abspath(ld.path)
+        ld.transport.abspath(ld.path)
         self.assertEqual([], self._calls)
 
 
 class TestLockHeldInfo(TestCaseInTempDir):
     """Can get information about the lock holder, and detect whether they're
-    still alive."""
+    still alive.
+    """
 
     def test_repr(self):
         info = LockHeldInfo.for_this_process(None)
@@ -645,8 +657,9 @@ class TestLockHeldInfo(TestCaseInTempDir):
 
     def test_unicode(self):
         info = LockHeldInfo.for_this_process(None)
-        self.assertContainsRe(str(info),
-                              r'held by .* on .* \(process #\d+\), acquired .* ago')
+        self.assertContainsRe(
+            str(info), r"held by .* on .* \(process #\d+\), acquired .* ago"
+        )
 
     def test_is_locked_by_this_process(self):
         info = LockHeldInfo.for_this_process(None)
@@ -654,7 +667,7 @@ class TestLockHeldInfo(TestCaseInTempDir):
 
     def test_is_not_locked_by_this_process(self):
         info = LockHeldInfo.for_this_process(None)
-        info.info_dict['pid'] = '123123123123123'
+        info.info_dict["pid"] = "123123123123123"
         self.assertFalse(info.is_locked_by_this_process())
 
     def test_lock_holder_live_process(self):
@@ -664,24 +677,23 @@ class TestLockHeldInfo(TestCaseInTempDir):
 
     def test_lock_holder_dead_process(self):
         """Detect that the holder (this process) is still running."""
-        self.overrideAttr(lockdir, 'get_host_name',
-                          lambda: 'aproperhostname')
+        self.overrideAttr(lockdir, "get_host_name", lambda: "aproperhostname")
         info = LockHeldInfo.for_this_process(None)
-        info.info_dict['pid'] = '123123123'
+        info.info_dict["pid"] = "123123123"
         self.assertTrue(info.is_lock_holder_known_dead())
 
     def test_lock_holder_other_machine(self):
         """The lock holder isn't here so we don't know if they're alive."""
         info = LockHeldInfo.for_this_process(None)
-        info.info_dict['hostname'] = 'egg.example.com'
-        info.info_dict['pid'] = '123123123'
+        info.info_dict["hostname"] = "egg.example.com"
+        info.info_dict["pid"] = "123123123"
         self.assertFalse(info.is_lock_holder_known_dead())
 
     def test_lock_holder_other_user(self):
         """Only auto-break locks held by this user."""
         info = LockHeldInfo.for_this_process(None)
-        info.info_dict['user'] = 'notme@example.com'
-        info.info_dict['pid'] = '123123123'
+        info.info_dict["user"] = "notme@example.com"
+        info.info_dict["pid"] = "123123123"
         self.assertFalse(info.is_lock_holder_known_dead())
 
     def test_no_good_hostname(self):
@@ -692,10 +704,9 @@ class TestLockHeldInfo(TestCaseInTempDir):
         So even if the process is known not to be alive, we can't say that's
         known for sure.
         """
-        self.overrideAttr(lockdir, 'get_host_name',
-                          lambda: 'localhost')
+        self.overrideAttr(lockdir, "get_host_name", lambda: "localhost")
         info = LockHeldInfo.for_this_process(None)
-        info.info_dict['pid'] = '123123123'
+        info.info_dict["pid"] = "123123123"
         self.assertFalse(info.is_lock_holder_known_dead())
 
 
@@ -710,32 +721,27 @@ class TestStaleLockDir(TestCaseWithTransport):
 
         This generates a warning but no other user interaction.
         """
-        self.overrideAttr(lockdir, 'get_host_name',
-                          lambda: 'aproperhostname')
+        self.overrideAttr(lockdir, "get_host_name", lambda: "aproperhostname")
         # Stealing dead locks is enabled by default.
         # Create a lock pretending to come from a different nonexistent
         # process on the same machine.
-        l1 = LockDir(self.get_transport(), 'a',
-                     extra_holder_info={'pid': '12312313'})
-        token_1 = l1.attempt_lock()
-        l2 = LockDir(self.get_transport(), 'a')
-        token_2 = l2.attempt_lock()
+        l1 = LockDir(self.get_transport(), "a", extra_holder_info={"pid": "12312313"})
+        l1.attempt_lock()
+        l2 = LockDir(self.get_transport(), "a")
+        l2.attempt_lock()
         # l1 will notice its lock was stolen.
-        self.assertRaises(errors.LockBroken,
-                          l1.unlock)
+        self.assertRaises(errors.LockBroken, l1.unlock)
         l2.unlock()
 
     def test_auto_break_stale_lock_configured_off(self):
-        """Automatic breaking can be turned off"""
-        l1 = LockDir(self.get_transport(), 'a',
-                     extra_holder_info={'pid': '12312313'})
+        """Automatic breaking can be turned off."""
+        l1 = LockDir(self.get_transport(), "a", extra_holder_info={"pid": "12312313"})
         # Stealing dead locks is enabled by default, so disable it.
-        config.GlobalStack().set('locks.steal_dead', False)
-        token_1 = l1.attempt_lock()
+        config.GlobalStack().set("locks.steal_dead", False)
+        l1.attempt_lock()
         self.addCleanup(l1.unlock)
-        l2 = LockDir(self.get_transport(), 'a')
+        l2 = LockDir(self.get_transport(), "a")
         # This fails now, because dead lock breaking is disabled.
-        self.assertRaises(LockContention,
-                          l2.attempt_lock)
+        self.assertRaises(LockContention, l2.attempt_lock)
         # and it's in fact not broken
         l1.confirm()
