@@ -16,45 +16,36 @@
 
 import socketserver
 
-from ..mergeable import read_mergeable_from_url
+from .. import errors, tests
+from ..bzr.tests import test_read_bundle
 from ..directory_service import directories
-from .. import (
-    errors,
-    tests,
-    )
-from ..bzr.tests import (
-    test_read_bundle,
-    )
-from . import (
-    test_server,
-    )
+from ..mergeable import read_mergeable_from_url
+from . import test_server
 
 
 class TestReadMergeableFromUrl(tests.TestCaseWithTransport):
-
     def test_read_mergeable_skips_local(self):
-        """A local bundle named like the URL should not be read.
-        """
+        """A local bundle named like the URL should not be read."""
         out, wt = test_read_bundle.create_bundle_file(self)
 
-        class FooService(object):
-            """A directory service that always returns source"""
+        class FooService:
+            """A directory service that always returns source."""
 
             def look_up(self, name, url):
-                return 'source'
-        directories.register('foo:', FooService, 'Testing directory service')
-        self.addCleanup(directories.remove, 'foo:')
-        self.build_tree_contents([('./foo:bar', out.getvalue())])
-        self.assertRaises(errors.NotABundle, read_mergeable_from_url,
-                          'foo:bar')
+                return "source"
+
+        directories.register("foo:", FooService, "Testing directory service")
+        self.addCleanup(directories.remove, "foo:")
+        self.build_tree_contents([("./foo:bar", out.getvalue())])
+        self.assertRaises(errors.NotABundle, read_mergeable_from_url, "foo:bar")
 
     def test_infinite_redirects_are_not_a_bundle(self):
-        """If a URL causes TooManyRedirections then NotABundle is raised.
-        """
+        """If a URL causes TooManyRedirections then NotABundle is raised."""
         from .blackbox.test_push import RedirectingMemoryServer
+
         server = RedirectingMemoryServer()
         self.start_server(server)
-        url = server.get_url() + 'infinite-loop'
+        url = server.get_url() + "infinite-loop"
         self.assertRaises(errors.NotABundle, read_mergeable_from_url, url)
 
     def test_smart_server_connection_reset(self):
@@ -78,13 +69,11 @@ class DisconnectingHandler(socketserver.BaseRequestHandler):
 
 
 class DisconnectingServer(test_server.TestingTCPServerInAThread):
-
     def __init__(self):
-        super(DisconnectingServer, self).__init__(
-            ('127.0.0.1', 0),
-            test_server.TestingTCPServer,
-            DisconnectingHandler)
+        super().__init__(
+            ("127.0.0.1", 0), test_server.TestingTCPServer, DisconnectingHandler
+        )
 
     def get_url(self):
-        """Return the url of the server"""
+        """Return the url of the server."""
         return "bzr://%s:%d/" % self.server.server_address
