@@ -22,66 +22,74 @@ from .. import mergetools, tests
 
 
 class TestFilenameSubstitution(tests.TestCaseInTempDir):
-
     def test_simple_filename(self):
-        cmd_list = ['kdiff3', '{base}', '{this}', '{other}', '-o', '{result}']
-        args, tmpfile = mergetools._subst_filename(cmd_list, 'test.txt')
+        cmd_list = ["kdiff3", "{base}", "{this}", "{other}", "-o", "{result}"]
+        args, tmpfile = mergetools._subst_filename(cmd_list, "test.txt")
         self.assertEqual(
-            ['kdiff3',
-             'test.txt.BASE',
-             'test.txt.THIS',
-             'test.txt.OTHER',
-             '-o',
-             'test.txt'],
-            args)
+            [
+                "kdiff3",
+                "test.txt.BASE",
+                "test.txt.THIS",
+                "test.txt.OTHER",
+                "-o",
+                "test.txt",
+            ],
+            args,
+        )
 
     def test_spaces(self):
-        cmd_list = ['kdiff3', '{base}', '{this}', '{other}', '-o', '{result}']
-        args, tmpfile = mergetools._subst_filename(cmd_list,
-                                                   'file with space.txt')
+        cmd_list = ["kdiff3", "{base}", "{this}", "{other}", "-o", "{result}"]
+        args, tmpfile = mergetools._subst_filename(cmd_list, "file with space.txt")
         self.assertEqual(
-            ['kdiff3',
-             'file with space.txt.BASE',
-             'file with space.txt.THIS',
-             'file with space.txt.OTHER',
-             '-o',
-             'file with space.txt'],
-            args)
+            [
+                "kdiff3",
+                "file with space.txt.BASE",
+                "file with space.txt.THIS",
+                "file with space.txt.OTHER",
+                "-o",
+                "file with space.txt",
+            ],
+            args,
+        )
 
     def test_spaces_and_quotes(self):
-        cmd_list = ['kdiff3', '{base}', '{this}', '{other}', '-o', '{result}']
+        cmd_list = ["kdiff3", "{base}", "{this}", "{other}", "-o", "{result}"]
         args, tmpfile = mergetools._subst_filename(
-            cmd_list, 'file with "space and quotes".txt')
+            cmd_list, 'file with "space and quotes".txt'
+        )
         self.assertEqual(
-            ['kdiff3',
-             'file with "space and quotes".txt.BASE',
-             'file with "space and quotes".txt.THIS',
-             'file with "space and quotes".txt.OTHER',
-             '-o',
-             'file with "space and quotes".txt'],
-            args)
+            [
+                "kdiff3",
+                'file with "space and quotes".txt.BASE',
+                'file with "space and quotes".txt.THIS',
+                'file with "space and quotes".txt.OTHER',
+                "-o",
+                'file with "space and quotes".txt',
+            ],
+            args,
+        )
 
     def test_tempfile(self):
-        self.build_tree(('test.txt', 'test.txt.BASE', 'test.txt.THIS',
-                         'test.txt.OTHER'))
-        cmd_list = ['some_tool', '{this_temp}']
-        args, tmpfile = mergetools._subst_filename(cmd_list, 'test.txt')
+        self.build_tree(
+            ("test.txt", "test.txt.BASE", "test.txt.THIS", "test.txt.OTHER")
+        )
+        cmd_list = ["some_tool", "{this_temp}"]
+        args, tmpfile = mergetools._subst_filename(cmd_list, "test.txt")
         self.assertPathExists(tmpfile)
         os.remove(tmpfile)
 
 
 class TestCheckAvailability(tests.TestCaseInTempDir):
-
     def test_full_path(self):
         self.assertTrue(mergetools.check_availability(sys.executable))
 
     def test_nonexistent(self):
-        self.assertFalse(mergetools.check_availability('DOES NOT EXIST'))
+        self.assertFalse(mergetools.check_availability("DOES NOT EXIST"))
 
     def test_non_executable(self):
         f, name = tempfile.mkstemp()
         try:
-            self.log('temp filename: %s', name)
+            self.log("temp filename: %s", name)
             self.assertFalse(mergetools.check_availability(name))
         finally:
             os.close(f)
@@ -93,26 +101,29 @@ class TestInvoke(tests.TestCaseInTempDir):
         super(tests.TestCaseInTempDir, self).setUp()
         self._exe = None
         self._args = None
-        self.build_tree_contents((
-            ('test.txt', b'stuff'),
-            ('test.txt.BASE', b'base stuff'),
-            ('test.txt.THIS', b'this stuff'),
-            ('test.txt.OTHER', b'other stuff'),
-        ))
+        self.build_tree_contents(
+            (
+                ("test.txt", b"stuff"),
+                ("test.txt.BASE", b"base stuff"),
+                ("test.txt.THIS", b"this stuff"),
+                ("test.txt.OTHER", b"other stuff"),
+            )
+        )
 
     def test_invoke_expands_exe_path(self):
-        self.overrideEnv('PATH', os.path.dirname(sys.executable))
+        self.overrideEnv("PATH", os.path.dirname(sys.executable))
 
         def dummy_invoker(exe, args, cleanup):
             self._exe = exe
             self._args = args
             cleanup(0)
             return 0
-        command = '%s {result}' % os.path.basename(sys.executable)
-        retcode = mergetools.invoke(command, 'test.txt', dummy_invoker)
+
+        command = "{} {{result}}".format(os.path.basename(sys.executable))
+        retcode = mergetools.invoke(command, "test.txt", dummy_invoker)
         self.assertEqual(0, retcode)
         self.assertEqual(sys.executable, self._exe)
-        self.assertEqual(['test.txt'], self._args)
+        self.assertEqual(["test.txt"], self._args)
 
     def test_success(self):
         def dummy_invoker(exe, args, cleanup):
@@ -120,10 +131,11 @@ class TestInvoke(tests.TestCaseInTempDir):
             self._args = args
             cleanup(0)
             return 0
-        retcode = mergetools.invoke('tool {result}', 'test.txt', dummy_invoker)
+
+        retcode = mergetools.invoke("tool {result}", "test.txt", dummy_invoker)
         self.assertEqual(0, retcode)
-        self.assertEqual('tool', self._exe)
-        self.assertEqual(['test.txt'], self._args)
+        self.assertEqual("tool", self._exe)
+        self.assertEqual(["test.txt"], self._args)
 
     def test_failure(self):
         def dummy_invoker(exe, args, cleanup):
@@ -131,26 +143,27 @@ class TestInvoke(tests.TestCaseInTempDir):
             self._args = args
             cleanup(1)
             return 1
-        retcode = mergetools.invoke('tool {result}', 'test.txt', dummy_invoker)
+
+        retcode = mergetools.invoke("tool {result}", "test.txt", dummy_invoker)
         self.assertEqual(1, retcode)
-        self.assertEqual('tool', self._exe)
-        self.assertEqual(['test.txt'], self._args)
+        self.assertEqual("tool", self._exe)
+        self.assertEqual(["test.txt"], self._args)
 
     def test_success_tempfile(self):
         def dummy_invoker(exe, args, cleanup):
             self._exe = exe
             self._args = args
             self.assertPathExists(args[0])
-            with open(args[0], 'w') as f:
-                f.write('temp stuff')
+            with open(args[0], "w") as f:
+                f.write("temp stuff")
             cleanup(0)
             return 0
-        retcode = mergetools.invoke('tool {this_temp}', 'test.txt',
-                                    dummy_invoker)
+
+        retcode = mergetools.invoke("tool {this_temp}", "test.txt", dummy_invoker)
         self.assertEqual(0, retcode)
-        self.assertEqual('tool', self._exe)
+        self.assertEqual("tool", self._exe)
         self.assertPathDoesNotExist(self._args[0])
-        self.assertFileEqual(b'temp stuff', 'test.txt')
+        self.assertFileEqual(b"temp stuff", "test.txt")
 
     def test_failure_tempfile(self):
         def dummy_invoker(exe, args, cleanup):
@@ -158,13 +171,13 @@ class TestInvoke(tests.TestCaseInTempDir):
             self._args = args
             self.assertPathExists(args[0])
             self.log(repr(args))
-            with open(args[0], 'w') as f:
+            with open(args[0], "w") as f:
                 self.log(repr(f))
-                f.write('temp stuff')
+                f.write("temp stuff")
             cleanup(1)
             return 1
-        retcode = mergetools.invoke('tool {this_temp}', 'test.txt',
-                                    dummy_invoker)
+
+        retcode = mergetools.invoke("tool {this_temp}", "test.txt", dummy_invoker)
         self.assertEqual(1, retcode)
-        self.assertEqual('tool', self._exe)
-        self.assertFileEqual(b'stuff', 'test.txt')
+        self.assertEqual("tool", self._exe)
+        self.assertFileEqual(b"stuff", "test.txt")
