@@ -16,41 +16,42 @@
 
 # "weren't nothing promised to you.  do i look like i got a promise face?"
 
-"""Tests for trace library"""
+"""Tests for trace library."""
 
 import errno
-from io import StringIO
 import logging
 import os
 import re
 import sys
 import tempfile
+from io import StringIO
 
-from .. import (
-    debug,
-    errors,
-    trace,
-    )
-from . import features, TestCaseInTempDir, TestCase, TestSkipped
+from .. import debug, errors, trace
 from ..trace import (
-    mutter, mutter_callsite, report_exception,
-    set_verbosity_level, get_verbosity_level, is_quiet, is_verbose, be_quiet,
+    _rollover_trace_maybe,
+    be_quiet,
+    get_verbosity_level,
+    is_quiet,
+    is_verbose,
+    mutter,
+    mutter_callsite,
     pop_log_file,
     push_log_file,
-    _rollover_trace_maybe,
+    report_exception,
+    set_verbosity_level,
     show_error,
-    )
+)
+from . import TestCase, TestCaseInTempDir, TestSkipped, features
 
 
 def _format_exception():
-    """Format an exception as it would normally be displayed to the user"""
+    """Format an exception as it would normally be displayed to the user."""
     buf = StringIO()
     report_exception(sys.exc_info(), buf)
     return buf.getvalue()
 
 
 class TestTrace(TestCase):
-
     def test_format_sys_exception(self):
         # Test handling of an internal/unexpected error that probably
         # indicates a bug in brz.  The details of the message may vary
@@ -60,10 +61,8 @@ class TestTrace(TestCase):
             raise NotImplementedError("time travel")
         except NotImplementedError:
             err = _format_exception()
-        self.assertContainsRe(err,
-                              '^brz: ERROR: NotImplementedError: time travel')
-        self.assertContainsRe(err,
-                              'Breezy has encountered an internal error.')
+        self.assertContainsRe(err, "^brz: ERROR: NotImplementedError: time travel")
+        self.assertContainsRe(err, "Breezy has encountered an internal error.")
 
     def test_format_interrupt_exception(self):
         try:
@@ -71,7 +70,7 @@ class TestTrace(TestCase):
         except KeyboardInterrupt:
             # XXX: Some risk that a *real* keyboard interrupt won't be seen
             msg = _format_exception()
-        self.assertEqual(msg, 'brz: interrupted\n')
+        self.assertEqual(msg, "brz: interrupted\n")
 
     def test_format_memory_error(self):
         try:
@@ -79,80 +78,78 @@ class TestTrace(TestCase):
         except MemoryError:
             msg = _format_exception()
         self.assertEqual(
-            msg,
-            "brz: out of memory\nUse -Dmem_dump to dump memory to a file.\n")
+            msg, "brz: out of memory\nUse -Dmem_dump to dump memory to a file.\n"
+        )
 
     def test_format_mem_dump(self):
         self.requireFeature(features.meliae)
-        debug.debug_flags.add('mem_dump')
+        debug.debug_flags.add("mem_dump")
         try:
             raise MemoryError()
         except MemoryError:
             msg = _format_exception()
-        self.assertStartsWith(msg,
-                              "brz: out of memory\nMemory dumped to ")
+        self.assertStartsWith(msg, "brz: out of memory\nMemory dumped to ")
 
     def test_format_os_error(self):
         try:
-            os.rmdir('nosuchfile22222')
+            os.rmdir("nosuchfile22222")
         except OSError as e:
             e_str = str(e)
             msg = _format_exception()
         # Linux seems to give "No such file" but Windows gives "The system
         # cannot find the file specified".
-        self.assertEqual('brz: ERROR: {}\n'.format(e_str), msg)
+        self.assertEqual("brz: ERROR: {}\n".format(e_str), msg)
 
     def test_format_io_error(self):
         try:
-            open('nosuchfile22222')
+            open("nosuchfile22222")
         except OSError:
             msg = _format_exception()
         # Even though Windows and Linux differ for 'os.rmdir', they both give
         # 'No such file' for open()
         # However it now gets translated so we can not test for a specific
         # message
-        self.assertContainsRe(msg,
-                              '^brz: ERROR: \\[Errno .*\\] .*nosuchfile')
+        self.assertContainsRe(msg, "^brz: ERROR: \\[Errno .*\\] .*nosuchfile")
 
     def test_format_pywintypes_error(self):
         self.requireFeature(features.pywintypes)
         import pywintypes
         import win32file
+
         try:
-            win32file.RemoveDirectory('nosuchfile22222')
+            win32file.RemoveDirectory("nosuchfile22222")
         except pywintypes.error:
             msg = _format_exception()
         # GZ 2010-05-03: Formatting for pywintypes.error is basic, a 3-tuple
         #                with errno, function name, and locale error message
-        self.assertContainsRe(
-            msg, "^brz: ERROR: \\(2, 'RemoveDirectory[AW]?', .*\\)")
+        self.assertContainsRe(msg, "^brz: ERROR: \\(2, 'RemoveDirectory[AW]?', .*\\)")
 
     def test_format_sockets_error(self):
         try:
             import socket
+
             sock = socket.socket()
             sock.send(b"This should fail.")
         except OSError:
             msg = _format_exception()
 
-        self.assertNotContainsRe(msg,
-                                 "Traceback \\(most recent call last\\):")
+        self.assertNotContainsRe(msg, "Traceback \\(most recent call last\\):")
 
     def test_format_unicode_error(self):
         try:
-            raise errors.CommandError('argument foo\xb5 does not exist')
+            raise errors.CommandError("argument foo\xb5 does not exist")
         except errors.CommandError:
             msg = _format_exception()
-        expected = 'brz: ERROR: argument foo\xb5 does not exist\n'
+        expected = "brz: ERROR: argument foo\xb5 does not exist\n"
         self.assertEqual(msg, expected)
 
     def test_format_exception(self):
-        """Short formatting of brz exceptions"""
+        """Short formatting of brz exceptions."""
         try:
-            raise errors.NotBranchError('wibble')
+            raise errors.NotBranchError("wibble")
         except errors.NotBranchError:
             msg = _format_exception()
-        self.assertEqual(msg, 'brz: ERROR: Not a branch: \"wibble\".\n')
+        self.assertEqual(msg, 'brz: ERROR: Not a branch: "wibble".\n')
 
     def test_report_external_import_error(self):
         """Short friendly message for missing system modules."""
@@ -161,47 +158,47 @@ class TestTrace(TestCase):
         except ImportError:
             msg = _format_exception()
         else:
-            self.fail("somehow succeeded in importing %r" % ImaginaryModule)
+            self.fail("somehow succeeded in importing {!r}".format(ImaginaryModule))
         self.assertContainsRe(
             msg,
             "^brz: ERROR: No module named '?ImaginaryModule'?\n"
-            "You may need to install this Python library separately.\n$")
+            "You may need to install this Python library separately.\n$",
+        )
 
     def test_report_import_syntax_error(self):
         try:
             raise ImportError("syntax error")
         except ImportError:
             msg = _format_exception()
-        self.assertContainsRe(msg, 'Breezy has encountered an internal error')
+        self.assertContainsRe(msg, "Breezy has encountered an internal error")
 
     def test_trace_unicode(self):
-        """Write Unicode to trace log"""
-        self.log('the unicode character for benzene is \N{BENZENE RING}')
+        """Write Unicode to trace log."""
+        self.log("the unicode character for benzene is \N{BENZENE RING}")
         log = self.get_log()
         self.assertContainsRe(log, "the unicode character for benzene is")
 
     def test_trace_argument_unicode(self):
-        """Write a Unicode argument to the trace log"""
-        mutter('the unicode character for benzene is %s', '\N{BENZENE RING}')
+        """Write a Unicode argument to the trace log."""
+        mutter("the unicode character for benzene is %s", "\N{BENZENE RING}")
         log = self.get_log()
-        self.assertContainsRe(log, 'the unicode character')
+        self.assertContainsRe(log, "the unicode character")
 
     def test_trace_argument_utf8(self):
-        """Write a Unicode argument to the trace log"""
-        mutter('the unicode character for benzene is %s',
-               '\N{BENZENE RING}'.encode())
+        """Write a Unicode argument to the trace log."""
+        mutter("the unicode character for benzene is %s", "\N{BENZENE RING}".encode())
         log = self.get_log()
-        self.assertContainsRe(log, 'the unicode character')
+        self.assertContainsRe(log, "the unicode character")
 
     def test_trace_argument_exception(self):
-        err = Exception('an error')
-        mutter('can format stringable classes %s', err)
+        err = Exception("an error")
+        mutter("can format stringable classes %s", err)
         log = self.get_log()
-        self.assertContainsRe(log, 'can format stringable classes an error')
+        self.assertContainsRe(log, "can format stringable classes an error")
 
     def test_report_broken_pipe(self):
         try:
-            raise OSError(errno.EPIPE, 'broken pipe foofofo')
+            raise OSError(errno.EPIPE, "broken pipe foofofo")
         except OSError:
             msg = _format_exception()
             self.assertEqual(msg, "brz: broken pipe\n")
@@ -211,18 +208,18 @@ class TestTrace(TestCase):
     def assertLogContainsLine(self, log, string):
         """Assert log contains a line including log timestamp."""
         # Does not check absolute position in log as there may be kipple.
-        self.assertContainsRe(log,
-                              '(?m)^\\d+\\.\\d+  ' + re.escape(string))
+        self.assertContainsRe(log, "(?m)^\\d+\\.\\d+  " + re.escape(string))
 
     def test_mutter_callsite_1(self):
         """mutter_callsite can capture 1 level of stack frame."""
         mutter_callsite(1, "foo %s", "a string")
         log = self.get_log()
         # begin with the message
-        self.assertLogContainsLine(log, 'foo a string\nCalled from:\n')
+        self.assertLogContainsLine(log, "foo a string\nCalled from:\n")
         # should show two frame: this frame and the one above
         self.assertContainsRe(
-            log, 'test_trace\\.py", line \\d+, in test_mutter_callsite_1\n')
+            log, 'test_trace\\.py", line \\d+, in test_mutter_callsite_1\n'
+        )
         # this frame should be the final one
         self.assertEndsWith(log, ' "a string")\n')
 
@@ -231,50 +228,53 @@ class TestTrace(TestCase):
         mutter_callsite(2, "foo %s", "a string")
         log = self.get_log()
         # begin with the message
-        self.assertLogContainsLine(log, 'foo a string\nCalled from:\n')
+        self.assertLogContainsLine(log, "foo a string\nCalled from:\n")
         # should show two frame: this frame and the one above
         self.assertContainsRe(
-            log, 'test_trace.py", line \\d+, in test_mutter_callsite_2\n')
+            log, 'test_trace.py", line \\d+, in test_mutter_callsite_2\n'
+        )
         # this frame should be the final one
         self.assertEndsWith(log, ' "a string")\n')
 
     def test_mutter_never_fails(self):
         """Even with unencodable input mutter should not raise errors."""
-        mutter('can write unicode \xa7')
-        mutter('can interpolate unicode %s', '\xa7')
-        mutter(b'can write bytes \xa7')
-        mutter('can repr bytes %r', b'\xa7')
-        mutter('can interpolate bytes %s', b'\xa7')
+        mutter("can write unicode \xa7")
+        mutter("can interpolate unicode %s", "\xa7")
+        mutter(b"can write bytes \xa7")
+        mutter("can repr bytes %r", b"\xa7")
+        mutter("can interpolate bytes %s", b"\xa7")
         # Log will always be written as utf-8
         log = self.get_log()
         self.assertContainsRe(
             log,
-            '.* +can write unicode \xa7\n'
-            '.* +can interpolate unicode \xa7\n'
-            '.* +can write bytes \ufffd\n'
-            '.* +can repr bytes b\'\\\\xa7\'\n'
-            '.* +can interpolate bytes (?:\ufffd|b\'\\\\xa7\')\n')
+            ".* +can write unicode \xa7\n"
+            ".* +can interpolate unicode \xa7\n"
+            ".* +can write bytes \ufffd\n"
+            ".* +can repr bytes b'\\\\xa7'\n"
+            ".* +can interpolate bytes (?:\ufffd|b'\\\\xa7')\n",
+        )
 
     def test_show_error(self):
-        show_error('error1')
-        show_error('error2 \xb5 blah')
-        show_error('arg: %s', 'blah')
-        show_error('arg2: %(key)s', {'key': 'stuff'})
+        show_error("error1")
+        show_error("error2 \xb5 blah")
+        show_error("arg: %s", "blah")
+        show_error("arg2: %(key)s", {"key": "stuff"})
         try:
             raise Exception("oops")
         except BaseException:
-            show_error('kwarg', exc_info=True)
+            show_error("kwarg", exc_info=True)
         log = self.get_log()
-        self.assertContainsRe(log, 'error1')
-        self.assertContainsRe(log, 'error2 \xb5 blah')
-        self.assertContainsRe(log, 'arg: blah')
-        self.assertContainsRe(log, 'arg2: stuff')
-        self.assertContainsRe(log, 'kwarg')
-        self.assertContainsRe(log, 'Traceback \\(most recent call last\\):')
+        self.assertContainsRe(log, "error1")
+        self.assertContainsRe(log, "error2 \xb5 blah")
+        self.assertContainsRe(log, "arg: blah")
+        self.assertContainsRe(log, "arg2: stuff")
+        self.assertContainsRe(log, "kwarg")
+        self.assertContainsRe(log, "Traceback \\(most recent call last\\):")
         self.assertContainsRe(
-            log, 'File ".*test_trace.py", line .*, in test_show_error')
+            log, 'File ".*test_trace.py", line .*, in test_show_error'
+        )
         self.assertContainsRe(log, 'raise Exception\\("oops"\\)')
-        self.assertContainsRe(log, 'Exception: oops')
+        self.assertContainsRe(log, "Exception: oops")
 
     def test_push_log_file(self):
         """Can push and pop log file, and this catches mutter messages.
@@ -300,12 +300,12 @@ class TestTrace(TestCase):
             # have caused them to be flushed out.  need to match using regexps
             # as there's a timestamp at the front.
             tmp1.seek(0)
-            self.assertContainsRe(tmp1.read(),
-                                  b"\\d+\\.\\d+  comment to file1\n"
-                                  b"\\d+\\.\\d+  again to file1\n")
+            self.assertContainsRe(
+                tmp1.read(),
+                b"\\d+\\.\\d+  comment to file1\n\\d+\\.\\d+  again to file1\n",
+            )
             tmp2.seek(0)
-            self.assertContainsRe(tmp2.read(),
-                                  b"\\d+\\.\\d+  comment to file2\n")
+            self.assertContainsRe(tmp2.read(), b"\\d+\\.\\d+  comment to file2\n")
         finally:
             tmp1.close()
             tmp2.close()
@@ -314,39 +314,39 @@ class TestTrace(TestCase):
         # If _open_brz_log cannot open the file, then we should write the
         # warning to stderr. Since this is normally happening before logging is
         # set up.
-        self.overrideAttr(sys, 'stderr', StringIO())
+        self.overrideAttr(sys, "stderr", StringIO())
         # Set the log file to something that cannot exist
-        self.overrideEnv('BRZ_LOG', '/no-such-dir/brz.log')
-        self.overrideAttr(trace, '_brz_log_filename')
+        self.overrideEnv("BRZ_LOG", "/no-such-dir/brz.log")
+        self.overrideAttr(trace, "_brz_log_filename")
         logf = trace._open_brz_log()
-        if os.path.isdir('/no-such-dir'):
-            raise TestSkipped('directory creation succeeded')
+        if os.path.isdir("/no-such-dir"):
+            raise TestSkipped("directory creation succeeded")
         self.assertIs(None, logf)
         self.assertContainsRe(
             sys.stderr.getvalue(),
-            "failed to open trace file: .* '/no-such-dir/brz.log'$")
+            "failed to open trace file: .* '/no-such-dir/brz.log'$",
+        )
 
     def test__open_brz_log_ignores_cache_dir_error(self):
         # If the cache directory can not be created and _open_brz_log can thus
         # not open the file, then we should write the warning to stderr. Since
         # this is normally happening before logging is set up.
-        self.overrideAttr(sys, 'stderr', StringIO())
+        self.overrideAttr(sys, "stderr", StringIO())
         # Set the cache directory to something that cannot exist
-        self.overrideEnv('BRZ_LOG', None)
-        self.overrideEnv('BRZ_HOME', '/no-such-dir')
-        self.overrideEnv('XDG_CACHE_HOME', '/no-such-dir')
-        self.overrideAttr(trace, '_brz_log_filename')
+        self.overrideEnv("BRZ_LOG", None)
+        self.overrideEnv("BRZ_HOME", "/no-such-dir")
+        self.overrideEnv("XDG_CACHE_HOME", "/no-such-dir")
+        self.overrideAttr(trace, "_brz_log_filename")
         logf = trace._open_brz_log()
-        if os.path.isdir('/no-such-dir'):
-            raise TestSkipped('directory creation succeeded')
+        if os.path.isdir("/no-such-dir"):
+            raise TestSkipped("directory creation succeeded")
         self.assertIs(None, logf)
         self.assertContainsRe(
-            sys.stderr.getvalue(),
-            "failed to open trace file: .* '/no-such-dir'$")
+            sys.stderr.getvalue(), "failed to open trace file: .* '/no-such-dir'$"
+        )
 
 
 class TestVerbosityLevel(TestCase):
-
     def test_verbosity_level(self):
         set_verbosity_level(1)
         self.assertEqual(1, get_verbosity_level())
@@ -370,7 +370,7 @@ class TestVerbosityLevel(TestCase):
 
 
 class TestLogging(TestCase):
-    """Check logging functionality robustly records information"""
+    """Check logging functionality robustly records information."""
 
     def test_note(self):
         trace.note("Noted")
@@ -410,22 +410,24 @@ class TestLogging(TestCase):
         log = self.get_log()
         self.assertContainsString(log, "UnicodeDecodeError: ")
         self.assertContainsRe(
-            log, "Logging record unformattable: b?'\\\\xa7' % \\(\\)\n")
+            log, "Logging record unformattable: b?'\\\\xa7' % \\(\\)\n"
+        )
 
     def test_log_bytes_arg(self):
         logging.getLogger("brz").debug(b"%s", b"\xa7")
-        log = self.get_log()
+        self.get_log()
         self.assertEqual("   DEBUG  b'\\xa7'\n", self.get_log())
 
     def test_log_mixed_strings(self):
         logging.getLogger("brz").debug("%s", b"\xa7")
-        log = self.get_log()
+        self.get_log()
         self.assertEqual("   DEBUG  b'\\xa7'\n", self.get_log())
 
     def test_log_repr_broken(self):
         class BadRepr:
             def __repr__(self):
                 raise ValueError("Broken object")
+
         logging.getLogger("brz").debug("%s", BadRepr())
         log = self.get_log()
         self.assertContainsRe(log, "ValueError: Broken object\n")
@@ -433,11 +435,10 @@ class TestLogging(TestCase):
 
 
 class TestBzrLog(TestCaseInTempDir):
-
     def test_log_rollover(self):
-        temp_log_name = 'test-log'
-        trace_file = open(temp_log_name, 'a')
-        trace_file.writelines(['test_log_rollover padding\n'] * 200000)
+        temp_log_name = "test-log"
+        trace_file = open(temp_log_name, "a")
+        trace_file.writelines(["test_log_rollover padding\n"] * 200000)
         trace_file.close()
         _rollover_trace_maybe(temp_log_name)
         # should have been rolled over
@@ -445,7 +446,6 @@ class TestBzrLog(TestCaseInTempDir):
 
 
 class TestTraceConfiguration(TestCaseInTempDir):
-
     def test_default_config(self):
         config = trace.DefaultConfig()
         self.overrideAttr(trace, "_brz_log_filename", None)
