@@ -17,7 +17,6 @@
 
 """Tests for log+ transport decorator."""
 
-
 from breezy import transport
 from breezy.tests import TestCaseWithMemoryTransport
 from breezy.trace import mutter
@@ -25,23 +24,21 @@ from breezy.transport.log import TransportLogDecorator
 
 
 class TestTransportLog(TestCaseWithMemoryTransport):
-
     def test_log_transport(self):
-        base_transport = self.get_transport('')
-        logging_transport = transport.get_transport(
-            'log+' + base_transport.base)
+        base_transport = self.get_transport("")
+        logging_transport = transport.get_transport("log+" + base_transport.base)
 
         # operations such as mkdir are logged
-        mutter('where are you?')
-        logging_transport.mkdir('subdir')
+        mutter("where are you?")
+        logging_transport.mkdir("subdir")
         log = self.get_log()
         # GZ 2017-05-24: Used to expect abspath logged, logger needs fixing.
-        self.assertContainsRe(log, r'mkdir subdir')
-        self.assertContainsRe(log, '  --> None')
+        self.assertContainsRe(log, r"mkdir subdir")
+        self.assertContainsRe(log, "  --> None")
         # they have the expected effect
-        self.assertTrue(logging_transport.has('subdir'))
+        self.assertTrue(logging_transport.has("subdir"))
         # and they operate on the underlying transport
-        self.assertTrue(base_transport.has('subdir'))
+        self.assertTrue(base_transport.has("subdir"))
 
     def test_log_readv(self):
         # see <https://bugs.launchpad.net/bzr/+bug/340347>
@@ -53,24 +50,23 @@ class TestTransportLog(TestCaseWithMemoryTransport):
         # construct it directly to avoid needing the dummy transport to be
         # registered etc
         logging_transport = TransportLogDecorator(
-            'log+dummy:///', _decorated=base_transport)
+            "log+dummy:///", _decorated=base_transport
+        )
 
-        result = base_transport.readv('foo', [(0, 10)])
+        result = base_transport.readv("foo", [(0, 10)])
         # sadly there's no types.IteratorType, and GeneratorType is too
         # specific
         next(result)
 
-        result = logging_transport.readv('foo', [(0, 10)])
-        self.assertEqual(list(result),
-                         [(0, 'abcdefghij')])
+        result = logging_transport.readv("foo", [(0, 10)])
+        self.assertEqual(list(result), [(0, "abcdefghij")])
 
 
 class DummyReadvTransport:
-
-    base = 'dummy:///'
+    base = "dummy:///"
 
     def readv(self, filename, offset_length_pairs):
-        yield (0, 'abcdefghij')
+        yield (0, "abcdefghij")
 
     def abspath(self, path):
         return self.base + path
