@@ -16,22 +16,20 @@
 
 """Test uncommit."""
 
-
 from .. import errors, tests, uncommit
 
 
 class TestUncommit(tests.TestCaseWithTransport):
-
     def make_linear_tree(self):
-        tree = self.make_branch_and_tree('tree')
+        tree = self.make_branch_and_tree("tree")
         tree.lock_write()
         try:
-            self.build_tree(['tree/one'])
-            tree.add('one')
-            rev_id1 = tree.commit('one')
-            self.build_tree(['tree/two'])
-            tree.add('two')
-            rev_id2 = tree.commit('two')
+            self.build_tree(["tree/one"])
+            tree.add("one")
+            rev_id1 = tree.commit("one")
+            self.build_tree(["tree/two"])
+            tree.add("two")
+            rev_id2 = tree.commit("two")
         finally:
             tree.unlock()
         return tree, [rev_id1, rev_id2]
@@ -45,13 +43,13 @@ class TestUncommit(tests.TestCaseWithTransport):
         self.assertEqual((1, history[0]), tree.branch.last_revision_info())
 
         # The file should not be removed
-        self.assertPathExists('tree/two')
+        self.assertPathExists("tree/two")
         # And it should still be listed as added
-        self.assertTrue(tree.is_versioned('two'))
+        self.assertTrue(tree.is_versioned("two"))
 
     def test_uncommit_bound(self):
         tree, history = self.make_linear_tree()
-        child = tree.controldir.sprout('child').open_workingtree()
+        child = tree.controldir.sprout("child").open_workingtree()
         child.branch.bind(tree.branch)
 
         self.assertEqual(history[1], tree.last_revision())
@@ -70,7 +68,7 @@ class TestUncommit(tests.TestCaseWithTransport):
 
     def test_uncommit_bound_local(self):
         tree, history = self.make_linear_tree()
-        child = tree.controldir.sprout('child').open_workingtree()
+        child = tree.controldir.sprout("child").open_workingtree()
         child.branch.bind(tree.branch)
 
         self.assertEqual(history[1], tree.last_revision())
@@ -90,9 +88,13 @@ class TestUncommit(tests.TestCaseWithTransport):
         tree, history = self.make_linear_tree()
 
         # If this tree isn't bound, local=True raises an exception
-        self.assertRaises(errors.LocalRequiresBoundBranch,
-                          uncommit.uncommit, tree.branch, tree=tree,
-                          local=True)
+        self.assertRaises(
+            errors.LocalRequiresBoundBranch,
+            uncommit.uncommit,
+            tree.branch,
+            tree=tree,
+            local=True,
+        )
 
     def test_uncommit_remove_tags(self):
         tree, history = self.make_linear_tree()
@@ -103,19 +105,18 @@ class TestUncommit(tests.TestCaseWithTransport):
         uncommit.uncommit(tree.branch, tree=tree)
         self.assertEqual(history[0], tree.last_revision())
         self.assertEqual((1, history[0]), tree.branch.last_revision_info())
-        self.assertEqual({
-            "pointsatexisting": history[0]
-            }, tree.branch.tags.get_tag_dict())
+        self.assertEqual(
+            {"pointsatexisting": history[0]}, tree.branch.tags.get_tag_dict()
+        )
 
     def test_uncommit_remove_tags_keeps_pending_merges(self):
         tree, history = self.make_linear_tree()
-        copy = tree.controldir.sprout('copyoftree').open_workingtree()
-        copy.commit(message='merged', rev_id=b'merged')
+        copy = tree.controldir.sprout("copyoftree").open_workingtree()
+        copy.commit(message="merged", rev_id=b"merged")
         tree.merge_from_branch(copy.branch)
-        tree.branch.tags.set_tag('pointsatmerged', b'merged')
-        history.append(tree.commit('merge'))
-        self.assertEqual(
-            b'merged', tree.branch.tags.lookup_tag('pointsatmerged'))
+        tree.branch.tags.set_tag("pointsatmerged", b"merged")
+        history.append(tree.commit("merge"))
+        self.assertEqual(b"merged", tree.branch.tags.lookup_tag("pointsatmerged"))
         self.assertEqual(history[2], tree.last_revision())
         self.assertEqual((3, history[2]), tree.branch.last_revision_info())
         tree.branch.tags.set_tag("pointsatexisting", history[1])
@@ -123,11 +124,14 @@ class TestUncommit(tests.TestCaseWithTransport):
         uncommit.uncommit(tree.branch, tree=tree)
         self.assertEqual(history[1], tree.last_revision())
         self.assertEqual((2, history[1]), tree.branch.last_revision_info())
-        self.assertEqual([history[1], b'merged'], tree.get_parent_ids())
-        self.assertEqual({
-            "pointsatexisting": history[1],
-            "pointsatmerged": b'merged',
-            }, tree.branch.tags.get_tag_dict())
+        self.assertEqual([history[1], b"merged"], tree.get_parent_ids())
+        self.assertEqual(
+            {
+                "pointsatexisting": history[1],
+                "pointsatmerged": b"merged",
+            },
+            tree.branch.tags.get_tag_dict(),
+        )
 
     def test_uncommit_keep_tags(self):
         tree, history = self.make_linear_tree()
@@ -138,7 +142,10 @@ class TestUncommit(tests.TestCaseWithTransport):
         uncommit.uncommit(tree.branch, tree=tree, keep_tags=True)
         self.assertEqual(history[0], tree.last_revision())
         self.assertEqual((1, history[0]), tree.branch.last_revision_info())
-        self.assertEqual({
-            "pointsatexisting": history[0],
-            "pointsatremoved": history[1],
-            }, tree.branch.tags.get_tag_dict())
+        self.assertEqual(
+            {
+                "pointsatexisting": history[0],
+                "pointsatremoved": history[1],
+            },
+            tree.branch.tags.get_tag_dict(),
+        )
