@@ -26,8 +26,12 @@ from stat import S_IMODE, S_ISDIR, ST_MODE
 
 from .. import osutils, transport, urlutils
 
-_append_flags = os.O_CREAT | os.O_APPEND | os.O_WRONLY | osutils.O_BINARY | osutils.O_NOINHERIT
-_put_non_atomic_flags = os.O_CREAT | os.O_TRUNC | os.O_WRONLY | osutils.O_BINARY | osutils.O_NOINHERIT
+_append_flags = (
+    os.O_CREAT | os.O_APPEND | os.O_WRONLY | osutils.O_BINARY | osutils.O_NOINHERIT
+)
+_put_non_atomic_flags = (
+    os.O_CREAT | os.O_TRUNC | os.O_WRONLY | osutils.O_BINARY | osutils.O_NOINHERIT
+)
 
 
 class LocalTransport(transport.Transport):
@@ -35,23 +39,23 @@ class LocalTransport(transport.Transport):
 
     def __init__(self, base):
         """Set the base path where files will be stored."""
-        if not base.startswith('file://'):
-            raise AssertionError("not a file:// url: %r" % base)
-        if base[-1] != '/':
-            base = base + '/'
+        if not base.startswith("file://"):
+            raise AssertionError("not a file:// url: {!r}".format(base))
+        if base[-1] != "/":
+            base = base + "/"
 
         # Special case : windows has no "root", but does have
         # multiple lettered drives inside it. #240910
-        if sys.platform == 'win32' and base == 'file:///':
-            base = ''
-            self._local_base = ''
+        if sys.platform == "win32" and base == "file:///":
+            base = ""
+            self._local_base = ""
             super().__init__(base)
             return
 
         super().__init__(base)
         self._local_base = urlutils.local_path_from_url(base)
-        if self._local_base[-1] != '/':
-            self._local_base = self._local_base + '/'
+        if self._local_base[-1] != "/":
+            self._local_base = self._local_base + "/"
 
     def clone(self, offset=None):
         """Return a new LocalTransport with root at self.base + offset
@@ -62,7 +66,7 @@ class LocalTransport(transport.Transport):
             return LocalTransport(self.base)
         else:
             abspath = self.abspath(offset)
-            if abspath == 'file://':
+            if abspath == "file://":
                 # fix upwalk for UNC path
                 # when clone from //HOST/path updir recursively
                 # we should stop at least at //HOST part
@@ -76,7 +80,7 @@ class LocalTransport(transport.Transport):
          - relative_reference does not contain '..'
          - relative_reference is url escaped.
         """
-        if relative_reference in ('.', ''):
+        if relative_reference in (".", ""):
             # _local_base normally has a trailing slash; strip it so that stat
             # on a transport pointing to a symlink reads the link not the
             # referent but be careful of / and c:\
@@ -88,22 +92,22 @@ class LocalTransport(transport.Transport):
         # TODO: url escape the result. RBC 20060523.
         # jam 20060426 Using normpath on the real path, because that ensures
         #       proper handling of stuff like
-        path = osutils.normpath(osutils.pathjoin(
-            self._local_base, urlutils.unescape(relpath)))
+        path = osutils.normpath(
+            osutils.pathjoin(self._local_base, urlutils.unescape(relpath))
+        )
         # on windows, our _local_base may or may not have a drive specified
         # (ie, it may be "/" or "c:/foo").
         # If 'relpath' is '/' we *always* get back an abspath without
         # the drive letter - but if our transport already has a drive letter,
         # we want our abspaths to have a drive letter too - so handle that
         # here.
-        if (sys.platform == "win32" and self._local_base[1:2] == ":"
-                and path == '/'):
+        if sys.platform == "win32" and self._local_base[1:2] == ":" and path == "/":
             path = self._local_base[:3]
 
         return urlutils.local_path_to_url(path)
 
     def local_abspath(self, relpath):
-        """Transform the given relative path URL into the actual path on disk
+        """Transform the given relative path URL into the actual path on disk.
 
         This function only exists for the LocalTransport, since it is
         the only one that has direct local access.
@@ -119,10 +123,9 @@ class LocalTransport(transport.Transport):
         return urlutils.local_path_from_url(absurl)
 
     def relpath(self, abspath):
-        """Return the local path portion from a given absolute path.
-        """
+        """Return the local path portion from a given absolute path."""
         if abspath is None:
-            abspath = '.'
+            abspath = "."
 
         return urlutils.file_relpath(self.base, abspath)
 
@@ -139,7 +142,7 @@ class LocalTransport(transport.Transport):
             transport._file_streams[canonical_url].flush()
         try:
             path = self._abspath(relpath)
-            return open(path, 'rb')
+            return open(path, "rb")
         except OSError as e:
             if e.errno == errno.EISDIR:
                 return transport.LateReadError(relpath)
@@ -159,7 +162,7 @@ class LocalTransport(transport.Transport):
         try:
             path = self._abspath(relpath)
             osutils.check_legal_path(path)
-            fp = AtomicFile(path, 'wb', new_mode=mode)
+            fp = AtomicFile(path, "wb", new_mode=mode)
         except OSError as e:
             self._translate_error(e, path)
         try:
@@ -176,14 +179,14 @@ class LocalTransport(transport.Transport):
         :param raw_bytes:   String
         """
         from ..atomicfile import AtomicFile
+
         if not isinstance(raw_bytes, bytes):
-            raise TypeError(
-                'raw_bytes must be bytes, not %s' % type(raw_bytes))
+            raise TypeError("raw_bytes must be bytes, not {}".format(type(raw_bytes)))
         path = relpath
         try:
             path = self._abspath(relpath)
             osutils.check_legal_path(path)
-            fp = AtomicFile(path, 'wb', new_mode=mode)
+            fp = AtomicFile(path, "wb", new_mode=mode)
         except OSError as e:
             self._translate_error(e, path)
         try:
@@ -193,10 +196,9 @@ class LocalTransport(transport.Transport):
         finally:
             fp.close()
 
-    def _put_non_atomic_helper(self, relpath, writer,
-                               mode=None,
-                               create_parent_dir=False,
-                               dir_mode=None):
+    def _put_non_atomic_helper(
+        self, relpath, writer, mode=None, create_parent_dir=False, dir_mode=None
+    ):
         """Common functionality information for the put_*_non_atomic.
 
         This tracks all the create_parent_dir stuff.
@@ -219,8 +221,7 @@ class LocalTransport(transport.Transport):
         except OSError as e:
             # We couldn't create the file, maybe we need to create
             # the parent directory, and try again
-            if (not create_parent_dir
-                    or e.errno not in (errno.ENOENT, errno.ENOTDIR)):
+            if not create_parent_dir or e.errno not in (errno.ENOENT, errno.ENOTDIR):
                 self._translate_error(e, relpath)
             parent_dir = os.path.dirname(abspath)
             if not parent_dir:
@@ -242,9 +243,9 @@ class LocalTransport(transport.Transport):
         finally:
             os.close(fd)
 
-    def put_file_non_atomic(self, relpath, f, mode=None,
-                            create_parent_dir=False,
-                            dir_mode=None):
+    def put_file_non_atomic(
+        self, relpath, f, mode=None, create_parent_dir=False, dir_mode=None
+    ):
         """Copy the file-like object into the target location.
 
         This function is not strictly safe to use. It is only meant to
@@ -260,35 +261,52 @@ class LocalTransport(transport.Transport):
                         the parent directory does not exist, go ahead and
                         create it, and then try again.
         """
+
         def writer(fd):
             self._pump_to_fd(f, fd)
-        self._put_non_atomic_helper(relpath, writer, mode=mode,
-                                    create_parent_dir=create_parent_dir,
-                                    dir_mode=dir_mode)
 
-    def put_bytes_non_atomic(self, relpath: str, raw_bytes: bytes, mode=None,
-                             create_parent_dir=False, dir_mode=None):
+        self._put_non_atomic_helper(
+            relpath,
+            writer,
+            mode=mode,
+            create_parent_dir=create_parent_dir,
+            dir_mode=dir_mode,
+        )
+
+    def put_bytes_non_atomic(
+        self,
+        relpath: str,
+        raw_bytes: bytes,
+        mode=None,
+        create_parent_dir=False,
+        dir_mode=None,
+    ):
         def writer(fd):
             if raw_bytes:
                 os.write(fd, raw_bytes)
-        self._put_non_atomic_helper(relpath, writer, mode=mode,
-                                    create_parent_dir=create_parent_dir,
-                                    dir_mode=dir_mode)
+
+        self._put_non_atomic_helper(
+            relpath,
+            writer,
+            mode=mode,
+            create_parent_dir=create_parent_dir,
+            dir_mode=dir_mode,
+        )
 
     def iter_files_recursive(self):
         """Iter the relative paths of files in the transports sub-tree."""
-        queue = list(self.list_dir('.'))
+        queue = list(self.list_dir("."))
         while queue:
             relpath = queue.pop(0)
             st = self.stat(relpath)
             if S_ISDIR(st[ST_MODE]):
                 for i, basename in enumerate(self.list_dir(relpath)):
-                    queue.insert(i, relpath + '/' + basename)
+                    queue.insert(i, relpath + "/" + basename)
             else:
                 yield relpath
 
     def _mkdir(self, abspath, mode=None):
-        """Create a real directory, filtering through mode"""
+        """Create a real directory, filtering through mode."""
         if mode is None:
             # os.mkdir() will filter through umask
             local_mode = 0o777
@@ -312,7 +330,7 @@ class LocalTransport(transport.Transport):
         """See Transport.open_write_stream."""
         abspath = self._abspath(relpath)
         try:
-            handle = open(abspath, 'wb')
+            handle = open(abspath, "wb")
         except OSError as e:
             self._translate_error(e, abspath)
         handle.truncate()
@@ -322,7 +340,7 @@ class LocalTransport(transport.Transport):
         return transport.FileFileStream(self, relpath, handle)
 
     def _get_append_file(self, relpath, mode=None):
-        """Call os.open() for the given relpath"""
+        """Call os.open() for the given relpath."""
         file_abspath = self._abspath(relpath)
         if mode is None:
             # os.open() will automatically use the umask
@@ -335,7 +353,7 @@ class LocalTransport(transport.Transport):
             self._translate_error(e, relpath)
 
     def _check_mode_and_size(self, file_abspath, fd, mode=None):
-        """Check the mode of the file, and return the current size"""
+        """Check the mode of the file, and return the current size."""
         st = os.fstat(fd)
         if mode is not None and mode != S_IMODE(st.st_mode):
             # Because of umask, we may still need to chmod the file.
@@ -374,10 +392,11 @@ class LocalTransport(transport.Transport):
             os.write(to_fd, b)
 
     def copy(self, rel_from, rel_to):
-        """Copy the item at rel_from to the location at rel_to"""
+        """Copy the item at rel_from to the location at rel_to."""
         path_from = self._abspath(rel_from)
         path_to = self._abspath(rel_to)
         import shutil
+
         try:
             shutil.copy(path_from, path_to)
         except OSError as e:
@@ -397,7 +416,7 @@ class LocalTransport(transport.Transport):
             self._translate_error(e, path_from)
 
     def move(self, rel_from, rel_to):
-        """Move the item at rel_from to the location at rel_to"""
+        """Move the item at rel_from to the location at rel_to."""
         path_from = self._abspath(rel_from)
         path_to = self._abspath(rel_to)
 
@@ -409,7 +428,7 @@ class LocalTransport(transport.Transport):
             self._translate_error(e, path_from)
 
     def delete(self, relpath):
-        """Delete the item at relpath"""
+        """Delete the item at relpath."""
         path = relpath
         try:
             path = self._abspath(relpath)
@@ -436,7 +455,7 @@ class LocalTransport(transport.Transport):
             total = self._get_total(relpaths)
             count = 0
             for path in relpaths:
-                self._update_pb(pb, 'copy-to', count, total)
+                self._update_pb(pb, "copy-to", count, total)
                 try:
                     mypath = self._abspath(path)
                     otherpath = other._abspath(path)
@@ -467,8 +486,7 @@ class LocalTransport(transport.Transport):
         return [urlutils.escape(entry) for entry in entries]
 
     def stat(self, relpath):
-        """Return the stat information for a file.
-        """
+        """Return the stat information for a file."""
         path = relpath
         try:
             path = self._abspath(relpath)
@@ -478,9 +496,10 @@ class LocalTransport(transport.Transport):
 
     def lock_read(self, relpath):
         """Lock the given file for shared (read) access.
-        :return: A lock object, which should be passed to Transport.unlock()
+        :return: A lock object, which should be passed to Transport.unlock().
         """
         from breezy.lock import ReadLock
+
         path = relpath
         try:
             path = self._abspath(relpath)
@@ -490,11 +509,12 @@ class LocalTransport(transport.Transport):
 
     def lock_write(self, relpath):
         """Lock the given file for exclusive (write) access.
-        WARNING: many transports do not support this, so trying avoid using it
+        WARNING: many transports do not support this, so trying avoid using it.
 
         :return: A lock object, which should be passed to Transport.unlock()
         """
         from breezy.lock import WriteLock
+
         return WriteLock(self._abspath(relpath))
 
     def rmdir(self, relpath):
@@ -509,8 +529,7 @@ class LocalTransport(transport.Transport):
     def symlink(self, source, link_name):
         """See Transport.symlink."""
         abs_link_dirpath = urlutils.dirname(self.abspath(link_name))
-        source_rel = urlutils.file_relpath(
-            abs_link_dirpath, self.abspath(source))
+        source_rel = urlutils.file_relpath(abs_link_dirpath, self.abspath(source))
 
         try:
             os.symlink(source_rel, self._abspath(link_name))
@@ -525,6 +544,7 @@ class LocalTransport(transport.Transport):
             self._translate_error(e, relpath)
 
     if osutils.hardlinks_good():
+
         def hardlink(self, source, link_name):
             """See Transport.link."""
             try:
@@ -533,7 +553,7 @@ class LocalTransport(transport.Transport):
                 self._translate_error(e, source)
 
     def _can_roundtrip_unix_modebits(self):
-        if sys.platform == 'win32':
+        if sys.platform == "win32":
             # anyone else?
             return False
         else:
@@ -541,17 +561,18 @@ class LocalTransport(transport.Transport):
 
 
 class EmulatedWin32LocalTransport(LocalTransport):
-    """Special transport for testing Win32 [UNC] paths on non-windows"""
+    """Special transport for testing Win32 [UNC] paths on non-windows."""
 
     def __init__(self, base):
-        if base[-1] != '/':
-            base = base + '/'
+        if base[-1] != "/":
+            base = base + "/"
         super(LocalTransport, self).__init__(base)
         self._local_base = urlutils._win32_local_path_from_url(base)
 
     def abspath(self, relpath):
-        path = osutils._win32_normpath(osutils.pathjoin(
-            self._local_base, urlutils.unescape(relpath)))
+        path = osutils._win32_normpath(
+            osutils.pathjoin(self._local_base, urlutils.unescape(relpath))
+        )
         return urlutils._win32_local_path_to_url(path)
 
     def clone(self, offset=None):
@@ -563,7 +584,7 @@ class EmulatedWin32LocalTransport(LocalTransport):
             return EmulatedWin32LocalTransport(self.base)
         else:
             abspath = self.abspath(offset)
-            if abspath == 'file://':
+            if abspath == "file://":
                 # fix upwalk for UNC path
                 # when clone from //HOST/path updir recursively
                 # we should stop at least at //HOST part
@@ -574,4 +595,7 @@ class EmulatedWin32LocalTransport(LocalTransport):
 def get_test_permutations():
     """Return the permutations to be used in testing."""
     from ..tests import test_server
-    return [(LocalTransport, test_server.LocalURLServer), ]
+
+    return [
+        (LocalTransport, test_server.LocalURLServer),
+    ]
